



*This produces all descriptives, except for those of correlates of vote loss (which are in replication_7)




clear 
set more off 
set matsize 800

cd ${basedir}

********************************************************************************
*********************Descriptives, local elections******************************
********************************************************************************
	 
use Data/ready_to_output.dta
replace codi_pro=0

 foreach var in turnout bat_call_share nuls_share bat_nn_share bat_present{
gen `var'aux=`var'*100  
egen mean`var'=mean(`var'aux), by(year)
egen mean`var'by=mean(`var'aux), by(year bat_present_2007)
}


*Year of the ban is never used in the analysis
drop if year==2007

gen all_nationalists=bat_share+share_ea+share_pnv+share_pnvea+share_aralar+share_ee+nuls_share
gen spanish_left=(share_psoe+share_iu+share_iusplit+share_podemos+share_equo+share_verdes) 
gen spanish_right=(share_pp+share_cis+share_upyd+share_cds+share_ual) 
gen other_local=100-all_nationalists-spanish_right-spanish_left-blancs/(blancs+acandi+nuls)



global sumvars turnout bat_share  nuls_share bat_call_share  all_nationalists spanish_left spanish_right other_local cens  

label variable turnout "\\ Turnout"
label variable bat_share " [1em] Batasuna votes"
label variable bat_call_share " [1em] Batasuna Support"
label variable nuls_share " [1em] Null votes"
label variable bat_present " [1em] I(Batasuna list)"
label variable all_nationalists  " [1em] Vote Share Basque Nationalists"
label variable share_ea " [1em] Vote Share EA"
label variable share_pnvea " [1em] V. Share PNV-EA (joint lists)"
label variable spanish_left  " [1em] V. Share Federal Left"
label variable spanish_right  " [1em] V. Share Federal Right"
label variable other_local  " [1em] V. Share Other Local Parties"
label variable cens " [1em] Population size"

egen auxunique=group(post bat_present_2007)
unique ident, by(auxunique) gen(claux)
egen Clusters=max(claux), by(post bat_present_2007)
label variable Clusters "\# Clusters"

xtset ident

estpost tabstat	 $sumvars if bat_present_2007==0 & post==0,  ///
statistics(mean sd) columns(statistics) listwise
est store A
distinct ident if bat_present_2007==0 & post==0
estadd local clusters `r(ndistinct)' , replace

estpost tabstat	 $sumvars if bat_present_2007==0 & post==1,  ///
statistics(mean sd) columns(statistics) listwise
est store B 
distinct ident if bat_present_2007==0 & post==1
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $sumvars if bat_present_2007==1 & post==0,  ///
statistics(mean sd) columns(statistics) listwise
est store C
distinct ident  if bat_present_2007==1 & post==0
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $sumvars if bat_present_2007==1 & post==1,  ///
statistics(mean sd) columns(statistics) listwise
est store D  
distinct ident  if bat_present_2007==1 & post==1
estadd local clusters `r(ndistinct)' , replace   
  
estpost tabstat	 $sumvars if  post==0,  ///
statistics(mean sd) columns(statistics) listwise
est store E
distinct ident  if  post==0
estadd local clusters `r(ndistinct)' , replace   

estpost tabstat	 $sumvars if   post==1,  ///
statistics(mean sd) columns(statistics) listwise
est store F   
distinct ident  if   post==1
estadd local clusters `r(ndistinct)' , replace   


esttab A B C D E F  using paper/desc_local.tex,  main(mean) aux(sd) unstack  nostar   label   /*
*/ tex nogaps  nonumbers nomtitles  /*
*/ s(clusters  N,  label("\hline \addlinespace[1ex] Municipalities" "N" )) /* 
*/ prehead("{" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" "\begin{tabular}{l*{7}{c}}"	"\hline\hline" /*
*/ "Variable Name	&	\multicolumn{2}{c}{Treated}	& \multicolumn{2}{c}{Control}&	\multicolumn{2}{c}{Total}\\" /*	
*/ "\cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7}" 	"&	Pre	&	Post	&	Pre	&	Post	&	Pre & Post		\\ \hline"  ) /*
*/   nonotes postfoot(\hline\hline \multicolumn{7}{p{\linewidth}}{\footnotesize  Treated: municipalities in which Batasuna  was banned in 2007. /*
*/ Batasuna support is the  sum of Batasuna votes and Null votes. 2007 excluded from the sample. Standard deviations in parentheses.} /*	
*/ \end{tabular}} ) replace





 
********************************************************************************
**************************Descriptives, IV**************************************
********************************************************************************


bys ident: gen n=_n
keep if n==1

*Undo normalization
gen csc_plus=csc+2

global sumvars dum_elected csc_plus dum_three treatment

label variable dum_elected "I(Former Councilor)"
label variable csc_plus "[1em] Former Candidates"
label variable dum_three "[1em] I(Former Candidates $\leq$3)"
label variable treatment "[1em] I(Former Councilor)$\times$ I(Former Candidates$\leq$3) "

estpost tabstat	 $sumvars if  bat_present_2007==0,  ///
statistics(mean sd) columns(statistics) listwise
est store A
estpost tabstat	 $sumvars if  bat_present_2007==1,  ///
statistics(mean sd) columns(statistics) listwise
est store B   
estpost tabstat	 $sumvars,  ///
statistics(mean sd) columns(statistics) listwise
est store C   

esttab A B C using paper/desclinks.tex, main(mean) aux(sd) nostar nogaps unstack label stats(N, label("\hline \addlinespace[1ex] Municipalities")) ///
noobs nonote nomtitle nonumber tex noline	 prehead("") postfoot("") replace
 


********************************************************************************
*******************Descriptives, regional elections*****************************
******************************************************************************** 

clear 
use Data/global_dta.dta, replace
keep if tipo==5 & codi_pro!=31
sort codi_mun codi_pro
 
merge codi_mun codi_pro using Data/aux_regdesc.dta
  

gen turnout=(acandi+blancs+nuls)/cens
gen nuls_share=nuls/(acandi+blancs+nuls)
gen batea_share=bat_call_share+share_ea
gen bat_nn_share=bat_call_share-nuls_share
gen bat_aux=bat_nn_share if year!=2009
replace bat_aux=nuls_share if year==2009
replace bat_call_share=bat_aux

global sumvars turnout bat_share  nuls_share bat_call_share share_ea share_pnvea cens 
global sumvars turnout bat_share bat_call_share nuls_share cens
label variable turnout "\\ Turnout"
label variable bat_share "[1em] Batasuna votes"
label variable bat_call_share "[1em] Batasuna Support"
label variable nuls_share "[1em] Null votes"
label variable share_ea "[1em] Vote Share EA"
label variable share_pnvea "[1em] Vote Share PNV-EA (joint lists)"
label variable cens " [1em] Population size"



estpost tabstat	 $sumvars if m_bat_present_2007==0 & post==0,  ///
statistics(mean sd) columns(statistics) listwise
est store A
distinct ident if m_bat_present_2007==0 & post==0
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $sumvars if m_bat_present_2007==0 & post==1,  ///
statistics(mean sd) columns(statistics) listwise
est store B  
distinct ident if m_bat_present_2007==0 & post==1
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $sumvars if m_bat_present_2007==1 & post==0,  ///
statistics(mean sd) columns(statistics) listwise
est store C
distinct ident if m_bat_present_2007==1 & post==0
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $sumvars if m_bat_present_2007==1 & post==1,  ///
statistics(mean sd) columns(statistics) listwise
est store D    
distinct ident if m_bat_present_2007==1 & post==1
estadd local clusters `r(ndistinct)' , replace 
  
estpost tabstat	 $sumvars if  post==0,  ///
statistics(mean sd) columns(statistics) listwise
est store E
distinct ident  if  post==0
estadd local clusters `r(ndistinct)' , replace 
estpost tabstat	 $sumvars if   post==1,  ///
statistics(mean sd) columns(statistics) listwise
est store F   
distinct ident if   post==1
estadd local clusters `r(ndistinct)' , replace 
   


esttab A B C D E F  using paper/desc_regional.tex,  main(mean) aux(sd) unstack  nostar   label   /*
*/ tex nogaps  nonumbers nomtitles  /*
*/ s(clusters  N,  label("\hline \addlinespace[1ex] Municipalities" "N" )) /* 
*/ prehead("{" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" "\begin{tabular}{l*{7}{c}}"	"\hline\hline" /*
*/ "Variable Name	&	\multicolumn{2}{c}{Treated}	& \multicolumn{2}{c}{Control}&	\multicolumn{2}{c}{Total}\\" /*	
*/ "\cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7}" 	"&	Pre	&	Post	&	Pre	&	Post	&	Pre & Post		\\ \hline"  ) /*
*/   nonotes postfoot(\hline\hline \multicolumn{7}{p{\linewidth}}{\footnotesize  Treated: municipalities in which Batasuna  was banned in 2007. /*
*/ Batasuna support is the  sum of Batasuna votes and Null votes. Standard deviations in parentheses.} /*	
*/ \end{tabular}} ) replace


 




 

 
********************************************************************************
**********************Descriptives, street violence*****************************
******************************************************************************** 
 
clear all
  
use Data/kale_buesa.dta
gen post=1
replace post=0 if year==6
replace post=0 if year==7 & month<5

gen treatpost2007=m_bat_present_2007*post
gen treatment_post=treatment*post


egen groupleg=group(m_bat_present_1987 m_bat_present_1991 m_bat_present_1995 m_bat_present_1999)
gen logtotal=total
 

gen dumkale=0
replace dumkale=1 if total!=0

gen elecmonth=0
replace elecmonth=1 if month==5 & year==7

*Drop periods before 3 and after 27 as no events
sort year month
egen period=group(year month)
sum total if period<=3
drop if period<=3
drop period
sort year month
egen period=group(year month)
drop if period>27
 
 
global sumvars dumkale total 

label variable dumkale "\\ I(Street Terrorist Episode)"
label variable total  "[1em] \# Street Terrorist Episodes"
 

estpost tabstat	 $sumvars if m_bat_present_2007==0 & post==0,  ///
statistics(mean sd) columns(statistics) listwise
est store A
distinct ident if m_bat_present_2007==0 & post==0
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $sumvars if m_bat_present_2007==0 & post==1,  ///
statistics(mean sd) columns(statistics) listwise
est store B  
distinct ident if m_bat_present_2007==0 & post==1
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $sumvars if m_bat_present_2007==1 & post==0,  ///
statistics(mean sd) columns(statistics) listwise
est store C
distinct ident if m_bat_present_2007==1 & post==0
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $sumvars if m_bat_present_2007==1 & post==1,  ///
statistics(mean sd) columns(statistics) listwise
est store D  
distinct ident if m_bat_present_2007==1 & post==1
estadd local clusters `r(ndistinct)' , replace   
  
estpost tabstat	 $sumvars if  post==0,  ///
statistics(mean sd) columns(statistics) listwise
est store E
distinct ident if  post==0
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $sumvars if   post==1,  ///
statistics(mean sd) columns(statistics) listwise
est store F   
distinct ident if   post==1
estadd local clusters `r(ndistinct)' , replace 
  

 esttab A B C D E F  using paper/desc_kale.tex,  main(mean) aux(sd) unstack  nostar   label   /*
*/ tex nogaps  nonumbers nomtitles  /*
*/ s(clusters  N,  label("\hline \addlinespace[1ex] Municipalities" "N" )) /* 
*/ prehead("{" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" "\begin{tabular}{l*{7}{c}}"	"\hline\hline" /*
*/ "Variable Name	&	\multicolumn{2}{c}{Treated}	& \multicolumn{2}{c}{Control}&	\multicolumn{2}{c}{Total}\\" /*	
*/ "\cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7}" 	"&	Pre	&	Post	&	Pre	&	Post	&	Pre & Post		\\ \hline"  ) /*
*/   nonotes postfoot(\hline\hline \multicolumn{7}{p{\linewidth}}{\footnotesize  Treated: municipalities in which Batasuna  was banned in 2007. /*
*/ The unit of observation is a month by municipality. Standard deviations in parentheses.} /*	
*/ \end{tabular}} ) replace

 
