



*This files takes the raw data from municipal elections in different years,
*and puts it together, creating global.dta

*It loads data for all municipal elections in Spain, keeping the results of the
*Basque provinces

*For every election year, there are two source files, one for small  (<250 inhab)
*municipalities, and another one for large municipalities 

*The municipality identifier (ident) is a mix of the province identifier and the within
*province municipality identifier: codi_prov*1000+codi_mun
*It uniquely identifies municipalities

***Raw data files naming convention: nnxxaamm.dat
*nn is a code for data type. 
*xx is a code for election type. 04 indicates local elections
*aa indicates election year: 87, 91, ..., 15
*mm indicates election month: usually 05 or 06
	
	***Files with nn=06 contain for every electoral list in every non-small municipality  (>250 inhabitants) , the number of votes and seats received
	***Files with nn=12 contain for every electoral list in every small municipality (<250 inhabitants), the number of votes and seats received
	***Files with nn=05 contain for every electoral list in every non-small municipality, the population, the number of blank votes, invalid votes, and votes to electoral lists  
	***Files with nn=11 contain for every electoral list in every small municipality, the population, the number of blank votes, invalid votes, and votes to electoral lists
	***Files witn nn=03 contain information to identify electoral lists, like codes, cross-province codes, names, initials.

	
**More Documentation provided by the ministry is in Data/Ficheros.doc (in Spanish)

capture cd ${basedir}/Data
global sleep 250

***********************************nn=06****************************************
clear all
set more off
foreach codi in 048706 049105 049505 049906 040305 040705 041105 041505{
infix tipo 1-2 year 3-6 codi_pro 10-11 codi_mun 12-14 codi_candi 17-22 votos_candi 23-30 conce_candi 31-33 using 06`codi'.DAT
keep if codi_pro==01 | codi_pro==20  | codi_pro==48  
gen id=codi_pro*1000+codi_mun

sort codi_candi
save 06`codi'.dta, replace

clear
}


clear all
foreach codi in 048706 049105 049505 049906 040305 040705 041105 041505{
append using 06`codi'.dta
sleep $sleep
sleep $sleep
erase 06`codi'.dta

}

sort year tipo codi_candi
save 06.dta, replace

***********************************nn=12****************************************
clear all
foreach codi in 048706 049105 049505 049906 040305 040705 041105 041505{
infix tipo 1-2 year 3-6 codi_pro 10-11 codi_mun 12-14 codi_candi 15-20 votos_candi 21-23 conce_candi 24-25 votos_indiv_candi 120-122 using 12`codi'.DAT
keep if codi_pro==01 | codi_pro==20  | codi_pro==48 
gen id=codi_pro*1000+codi_mun

sort codi_candi
save 12`codi'.dta, replace

clear
}

clear all
foreach codi in 048706 049105 049505 049906 040305 040705 041105  041505 {
append using 12`codi'.dta
sleep $sleep
sleep $sleep
erase 12`codi'.dta
}


bysort year codi_mun codi_pro codi_candi:  gen dup = cond(_N==1,0,_n) 
keep if dup==0 | dup==1
drop dup votos_indiv_candi

save 12.dta, replace
append using 06.dta
sleep $sleep
sleep $sleep
erase 12.dta

gen tipold=tipo
*in small municipalities, local election code is 8 or 9
replace tipo=4 if tipo==8 | tipo==9
save 06.dta, replace


***********************************nn=05****************************************
clear all

foreach codi in 048706 049105 049505 049906 040305 040705 041105 041505{
infix tipo 1-2 year 3-6 codi_pro 12-13 codi_mun 14-16 cens 129-136 cens_escrutini 134-136 blancs 190-197 nuls 198-205 acandi 206-213 using 05`codi'.DAT
keep if codi_pro==01 | codi_pro==20  | codi_pro==48 

gen id=codi_pro*1000+codi_mun

save 05`codi'.dta, replace

clear
}


clear all

foreach codi in 048706 049105 049505 049906 040305 040705 041105 041505{
append using 05`codi'.dta
sleep $sleep
sleep $sleep
erase 05`codi'.dta
}

sort year tipo codi_mun codi_pro

save 05.dta, replace

***********************************nn=11****************************************


clear all

foreach codi in 048706 049105 049505 049906 040305 040705 041105 041505{
infix tipo 1-2 year 3-6 codi_pro 12-13 codi_mun 14-16 cens 134-136 blancs 149-151 nuls 152-154 acandi 155-157 using 11`codi'.DAT
keep if codi_pro==01 | codi_pro==20  | codi_pro==48  
gen id=codi_pro*1000+codi_mun

save 11`codi'.dta, replace

clear
}


clear all
foreach codi in 048706 049105 049505 049906 040305 040705 041105  041505{

append using 11`codi'.dta
sleep $sleep
sleep $sleep
sleep $sleep

erase 11`codi'.dta
}



append using 05.dta
gen tipold=tipo
*in small municipalities, local election code is 8 or 9
replace tipo=4 if tipo==8 | tipo==9

sort year tipo codi_mun codi_pro

save 05.dta, replace


***********************************nn=03****************************************
clear all

foreach codi in 048706 049105 049505 049906 040305 040705 041105 041505{
infix tipo 1-2 year 3-6 codi_candi 9-14 str siglas 15-64 str denominacion 65-214 cabecera_provincial 215-220 cabecera_auto 221-226 cabecera_estatal 227-232 using 03`codi'.DAT

save 03`codi'.dta, replace

clear
}


clear all

foreach codi in 048706 049105 049505 049906 040305 040705 041105 041505{
append using 03`codi'.dta
sleep $sleep
sleep $sleep
erase 03`codi'.dta

}

sort year tipo codi_candi

save 03.dta, replace
 

************************Put together the previous files*************************
clear all

use 06.dta

sort year tipo codi_candi

merge year tipo codi_candi using 03.dta 

keep if _merge==3
drop _merge

sort year tipo codi_mun codi_pro

merge year tipo codi_mun codi_pro using 05.dta

keep if _merge==3

drop _merge

*Drop Electoral lists receiving no votes
drop if votos_candi==0

egen sumconce=sum(conce_candi), by(tipo codi_mun codi_pro year)

*Add local election results
append using  p_eusk.dta
********************************************************************************
sleep $sleep
sleep $sleep
erase 06.dta
erase 03.dta
erase 05.dta
erase p_eusk.dta


********************************************************************************
***********HARMONIZE PARTY CODES ACROSS ELECTIONS AND MUNICIPALITIES************ 
*COMPUTE VOTE SHARES AND RESHAPE TO HAVE OBSERVATIONS AT THE MUNICIPALITY LEVEL*
******************************************************************************** 

replace denominacion=trim(denominacion)

*1) BATASUNA
gen batasuna=.
replace batasuna=votos_candi if denominacion=="HERRI BATASUNA" |denominacion=="Herri Batasuna" | denominacion=="COALICIÓN ELECTORAL HERRI BATASUNA" 
replace batasuna=votos_candi if denominacion=="HB" | denominacion=="Getariako Ezker Abertzaleen Batasuna" | denominacion=="Herri Lan Batasuna"
replace batasuna=votos_candi if denominacion=="AGRUPACION ELECTORES HERRI BATASUNA" 
replace batasuna=votos_candi if denominacion=="EUSKAL HERRITARROK" | denominacion=="EUSKAL HERRITARROK-ACCION MUNICIPAL OBRERA"
replace batasuna=votos_candi if denominacion=="EUSKAL HERRITARROK-AGRUPACION MUNICIPAL OBRERA" | denominacion=="EUSKAL HERRITARROK-CANDIDATURA UNITARIA ESTELLA"
replace batasuna=votos_candi if denominacion=="EUSKAL HERRITARROK-CENDEA UNIDA" | denominacion=="EH" | denominacion=="BATZARRE-EUSKAL HERRITARROK"
replace batasuna=votos_candi if denominacion=="PCTVEHAK"
replace batasuna=votos_candi if denominacion=="EUSKO ABERTZALE AKINTZA-ACCION NACIONALISTA VASCA"
replace batasuna=votos_candi if denominacion=="EUSKO ABERTZALE EKINTZ-ACCION NACIONALISTA VASCA"
replace batasuna=votos_candi if denominacion=="EUSKO ABERTZALE EKINTZA / ACCION NACIONALISTA VASC"
replace batasuna=votos_candi if denominacion=="EUSKO ABERTZALE EKINTZA ACCION NACIONALISTA VASCA"
replace batasuna=votos_candi if denominacion=="EUSKO ABERTZALE EKINTZA-ACCION NACIOLISTA VASCA"
replace batasuna=votos_candi if denominacion=="EUSKO ABERTZALE EKINTZA-ACCION NACIONALISTA VASCA"
replace batasuna=votos_candi if denominacion=="EUSKO ABERTZALE EKINTZA/ACCION NACIONALISTA VASCA"
replace batasuna=votos_candi if denominacion=="EUSKO EKINTZA ABERTZALEA"
replace batasuna=votos_candi if denominacion=="EAEANV"
replace batasuna=votos_candi if denominacion=="EUSKADIKO ABERTZALE EKINTZA ACCION NACIONALISTA VA"
replace batasuna=votos_candi if denominacion=="EUSKO ABERTZALE EKINZA/ ACCION NACIONALISTA VASCA"
replace batasuna=votos_candi if denominacion=="INIZIATIBA INTERNAZIONALISTA - HERRIEN ELKARTASUNA"
replace batasuna=votos_candi if denominacion=="AMAIUR"
replace batasuna=votos_candi if denominacion=="BILDU" | denominacion=="BILDU-EUSKO ALKARTASUNA (EA) /ALTERNATIBA ERAIKITZEN"|denominacion=="EHBILDU"
replace batasuna=votos_candi if denominacion=="EUSKAL HERRIA BILDU - HERRIEK ERABAKI" | denominacion=="EUSKAL HERRIA BILDU" |denominacion=="EH BILDU"

gen party="batasuna" if batasuna!=.
replace batasuna=0 if batasuna==.



*2) EA
local ea "EA" "EA" "EUSKO ALKARTASUNA" "EUSKO ALKARTASUNA (PEP)" "EUSKO ALKARTASUNA -SOLIDARIDAD VASCA" "EUSKO ALKARTASUNA-EUSKAL EZKERRA"   /*
*/ "COALICION EUSKO ALKARTASUNA-EUSKAL EZKERRA"

*3) PNV
replace denominacion="EUZKO ALDERDI JELTZALEA-PARTIDO NACIONALISTA VASCO" if siglas=="EAJ-PNV"
local pnv "EAJPNV" "EAJPNV" "PNV" "EUSKO ALDERDI JELTZALEA PARTIDO NACIONALISTA VASCO" "EUSKO ALDERDI JELTZALEA-PARTIDO NACIONALISTA VASCO" /*
*/"EUSKO ALDERDI JETZALEA-PARTIDO NACIONALISTA VASCO" "EUZKO ALDERDI JELTZALEA - PARTIDO NACIONALISTA VAS" /*
*/"EUZKO ALDERDI JELTZALEA - PARTIDO NACIONALISTA VASCO" "EUZKO ALDERDI JELTZALEA - PARTIDO NACIONALISTA VASCO - COALICIÓN POR EUROPA - EUROPARAKO KOALIZIOA"/*
*/"EUZKO ALDERDI JELTZALEA - PARTIDO NACIONALISTA VASCO-" "EUZKO ALDERDI JELTZALEA / PARTIDO NACIONALISTA VAS" /*
*/"EUZKO ALDERDI JELTZALEA PARTIDO NACIONALISTA VASCO" "EUZKO ALDERDI JELTZALEA-PARTIDO NACIONALISTA VASCO" /*
*/"EUZKO ALDERDI JELTZALEA-PARTIDO NACIONALISTA VASCO-COALICIÓN POR EUROPA-EUROPARAKO KOALIZIOA" /*
*/"EUZKO ALDERDI JELTZALEA-PNV (COALIC. NACIONALISTA)" "EUZKO ALDERDI JELTZALEA/ PARTIDO NACIONALISTA VASC" /*
*/"EUZKO ALDERDI JELZTALEA-PARTIDO NACIONALISTA VASCO" "PARTIDO NACIONALISTA VASCO" "PARTIDO NACIONALISTA VASCO-EUZKO ALDERDI JELTZALEA" /*
*/ "Partido Nacionalista Vasco" "EUZKO ALDERDI JELTZALEA-PARTIDO NACIONALISTA VASCO" "EUZKO ALDERDI JELTZALEA-PARTIDO NACIONALISTA VASCO (EAJ-PNV)" /*
*/ "GEROA BAI"


*4) PNV-EA
local pnvea "EAJPNVEA" "EAJPNVEA" "EA_EAJPNV" "EUZKO ALDERDI JELTZALEA-PNV / EUSKO ALKARTASUNA" "COALICION EA/EAJ-PNV" /*
*/ "COALICION EAJ-PNV/EA" "COALICION E.A.J.-P.N.V./E.A."

*5) PP
local pp "PP" "PP" "PARTIDO POPULAR"  "UNION DEL PUEBLO NAVARRA" "UNION DEL PUEBLO NAVARRO" /*
*/"UNION DEL PUEBLO NAVARRO CON PARTIDO POPULAR" "UNION DEL PUEBLO NAVARRO EN COALICION CON EL PARTIDO POPULAR" /*
*/"UNION DEL PUEBLO NAVARRO EN COALICION CON EL PP" "UNION DEL PUEBLO NAVARRO-A.P.-P.D.P." /* 
*/"UNION DEL PUEBLO NAVARRO-PARTIDO POPULAR" "UNION DEL PUEBLO NAVARRO-UPN" "UPN" /*
*/"ALIANZA POP.-P.DEMOC.POPULAR-P.DEMOC.LIBERAL-UCD" "ALIANZA POPULAR - PARTIDO DEMÓCRATA POPULAR - UNIÓ" /*
*/ "ALIANZA POPULAR-PARTIDO DEMÓCRATA POPULAR-UNIÓN LI" "AP" /*
*/ "UNION PUEBLO NAVARRO"  "UNIÓN DEL PUEBLO NAVARRO" "UNIÓN DEL PUEBLONAVARRO" "Unión del Pueblo Navarro" /*
*/ "APPDPUL" "APPL" "FEDERACION DE PARTIDOS DE ALIANZA POPULAR" "UNIÓN DEL PUEBLO NAVARRO EN COALICIÓN CON EL PARTIDO POPULAR" /*
*/ "UNIÓN DEL PUEBLO NAVARRO EN COALICIÓN CON EL PARTIDO POPULAR" "FAP"


*6) PSOE
replace denominacion="PSOE" if denominacion=="PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZKERRA (P" |denominacion=="PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZKERRA (PSOE) PSE-EE (PSOE))"
local psoe "PSOE" "PSOE" "PARTIDO SOCIALISTA" "PARTIDO SOCIALISTA DE EUSKADI" "PARTIDO SOCIALISTA DE EUSKADI - EUSKADIKO EZKERRA" /*
*/"PARTIDO SOCIALISTA DE EUSKADI-EUSKADI EZKERRA (PSOE)" "PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO ESKERRA"/*
*/"PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZKERRA (PSOE)" "PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZKERRA(PSOE)" /*
*/"PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZQUERRA" "PARTIDO SOCIALISTA DE EUSKADI-PARTIDO SOCIALISTA O" /*
*/"PARTIDO SOCIALISTA DE EUZKADI - PARTIDO SOCIALISTA" "PARTIDO SOCIALISTA DE LOS TRABAJADORES" /*
*/"PARTIDO SOCIALISTA DE NAVARRA" "PARTIDO SOCIALISTA DE NAVARRA- PSOE"  "PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZKERRA"/*
*/"PARTIDO SOCIALISTA DE NAVARRA-PSOE" "PARTIDO SOCIALISTA OBRERO ESPAÑOL" /*
*/"PARTIDO SOCIALISTA OBRERO ESPAÑOL - PROGRESISTAS" "PSEEEPSOE" "PSEPSOE" "PSNPSOE" /*
*/ "Partido Socialista Obrero Español" "EUSKADIKO EZKERRA" "EUSKADIKO EZKERRA - IZQUIERDA PARA EL SOCIALISMO" /*
*/"EUSKADIKO EZQUERRA" "EUSKADIKO EZQUERRA-(IP)" "EUSKADIKO EZQUERRA-IZDA. DE LOS PUEBLOS" /*
*/"Euskadiko Eskerra" "Euskadiko Ezkerra" "Euskadiko Ezquerra" /*
*/"PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZKERRA" "PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZKERRA (PSOE)" /*
*/"PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZKERRA (PSOE) PSE-EE (PSOE)"  /*
*/"PARTIDO SOCIALISTA DE EUSKADI-EUSKADIKO EZKERRA(PSOE)" "PARTIDO SOCIALISTA DE EUSKADI-EUSKADIO EZKERRA (PSOE)" /*
*/"PARTIDO SOCIALISTA DE NAVARRA" "PARTIDO SOCIALISTA DE NAVARRA - PSOE" "PARTIDO SOCIALISTA DE NAVARRA -PSOE" "PARTIDO SOCIALISTA DE NAVARRA- PSOE" /*
*/"PARTIDO SOCIALISTA DE NAVARRA-PSOE" "PSEEEPSOE"






*7) IU
*This makes sure denominations with special characters are picked up
gen auxiu =  strpos(denominacion, "EZKER BATUAK-BERDEAK/ARALAR/ZUTIK") > 0
replace denominacion="EB" if auxiu==1
replace auxiu=strpos(denominacion, "OKA (EZKER ANITZA - IU, EQUO, BERDEAK)") > 0
replace denominacion="EB" if auxiu==1
replace auxiu=  strpos(denominacion, "UDALBERRI - BILBAO EN COM") > 0
replace denominacion="EB" if auxiu==1
drop auxiu

local iu "EB" "EB"  "(IU)-EZKER BATUA" "Hondabarriko Exker Batua" "EZKER ANITZA - IZQUIERDA UNIDA - IRATZARRI - EKI: LA IZQUIERDA PLURAL" "EZKER ANTIKAPITALISTA-IZQUIERDA ANTICAPITALISTA-REVOLTA GLOBAL" /*
*/"EZKER BATUA" "EZKER BATUA - IZQUIERDA UNIDA" "EZKER BATUA / IZQUIERDA UNIDA" "EZKER BATUA BERDEAK (EB-B) - INDEPENDIENTES DE ABANTO Y ZIERBENA (INDAZ)"/*
*/"EZKER BATUA-ARALAR" "EZKER BATUA-BERDEAK" "EZKER BATUA-BERDEAK / ZUTIK" "EZKER BATUA-BERDEAK Y ARALAR"/*
*/"EZKER BATUA-BERDEAK-ALTERNATIVA" "EZKER BATUA-BERDEAK-ARALAR" "EZKER BATUA-BERDEAK: EZKERRA" "EZKER BATUA-IZQUIERDA UNIDA"/*
*/"EZKER BATUA-IZQUIERDA UNIDA BERDEAK" "EZKER BATUA/INDEPENDIENTEAK/ARALAR" "EZKER BATUAK-BERDEAK / ARALAR / ZUTIK" "EZKER BATUAK-BERDEAK Y ARALAR"/*
*/"EZKER BATUAK-BERDEAK/ARALAR/ZUTIK OÑATI EZKERRETIK" "EZKER BATUAREN ALDE"/*
*/"IU" "IU - LOS VERDES: LA IZQUIERDA PLURAL / EZKER ANITZA" "IUEB" "IUNNEB" "IUN_NEB" "IXN" /*
*/"IZQUIERDA UNIDA" "IZQUIERDA UNIDA - EZKER BATUA"/*
*/"IZQUIERDA UNIDA - EZKER BATUA DE NAVARRA" "IZQUIERDA UNIDA / EZKER BATUA"/*
*/"IZQUIERDA UNIDA DE NAVARRA" "IZQUIERDA UNIDA DE NAVARRA - NAFARROAKO EZKER BATU"/*
*/"IZQUIERDA UNIDA DE NAVARRA - NAFARROAKO EZKER BATUA" "IZQUIERDA UNIDA DE NAVARRA - NAFARROAKO EZKER BATUA - ALTERNATIVA"/*
*/"IZQUIERDA UNIDA DE NAVARRA-NAFARROAKO EZKER BATUA" "IZQUIERDA UNIDA DE NAVARRA-NAFARROAKO EZKER BATUA: LA IZQUIERDA"/*
*/"IZQUIERDA UNIDA-EZKER BATUA" "IZQUIERDA UNIDA-EZKER BATUA DE NAVARRA"/*
*/"IZQUIERDA UNIDA-LOS VERDES: LA IZQUIERDA PLURAL/EZKER ANITZA" "IZQUIERDA UNIDA-LOS VERDES: LA IZQUIERDA PLURAL/EZKER ANITZA (IU-LV)"/*
*/"IZQUIERDA UNIDA/EZKER BATUA DE NAVARRA" "EBARALAR"  "EBB"  /*
*/"IRABAZI" "IRABAZI - GANAR ANDOAIN (EZKER ANITZA - IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)"  /*
*/"IRABAZI - GANAR BASAURI (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI - GANAR ERMUA (EZKER ANITZA - IU, EQUO, ALTERNATIVA REPUBLICANA - INDEPENDIENTES)" /*
*/"IRABAZI - GANAR GASTEIZ (EZKER ANITZA - IU, EQUO, BERDEAK)" "IRABAZI - GANAR IRUÑA OKA (EZKER ANITZA - IU, EQUO, BERDEAK)" /*
*/"IRABAZI - GANAR ORDIZIA (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA INDEPENDIENTES)" /*
*/"IRABAZI - GANAR SESTAO (EZKER ANITZA - IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI - GANAR SOPELA (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI AZKOITIA BAI" "IRABAZI- GANAR ZARAUTZ (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR ARETXABALETA (EZKER ANITZA-IU, EQUO,ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR ARRASATE (EZKER ANITZA-IU, EQUO,ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR BARAKALDO (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /* 
*/"IRABAZI-GANAR BERANGO (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR BERGARA (EZKER ANITZA-IU, EQUO,ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR DONOSTIA (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR EIBAR (EZKER ANITZA-IU, EQUO,ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR ERANDIO (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR ESKORIATZA (EZKER ANITZA-IU, EQUO,ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR IRUN (EZKER ANITZA-IU,EQUO,ALTERNATIVA REPUBLICANA,INDEPENDIENTES)" /*
*/"IRABAZI-GANAR LEGAZPI (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR LEIOA (EZKER ANITZA -IU, EQUO, ALTERNATIVA REPUBLIANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR ORTUELLA (EZKER ANITZA-IU, ORTUELLAKO ALKARTASUNA, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR PASAIA (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR PORTUGALETE (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR SANTURTZI (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /* 
*/"IRABAZI-GANAR URRETXU (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR ZUMARRAGA (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANAR-GALDAKAO BIZIRIK (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" /*
*/"IRABAZI-GANARTRAPAGARAN (EZKER ANITZA-IU, EQUO, ALTERNATIVA REPUBLICANA, INDEPENDIENTES)" "IZQUIERDA UNIDA" "IZQUIERDA UNIDA- EZKERRA" /*
*/ "COALICION IZQUIERDA UNIDA" "COALICCION ELECTORAL IZQUIERDA-EZKERRA" "COALICION IZQUIERDA-EZKERRA (N)" /*
*/ "IZQEZK" "IZQUIERDA - EZKERRA" "IZQUIERDA-EZKERRA" "IZQUIERDA EZKERRA-ATARRABIAKO EZKERRA" "IZQUIERDA-EZKERRA DE BARAÑAIN -EQUO" /*
*/ "IZQUIERDA-EZKERRA-ANTSOAIN PUEDE (N)" "IZQUIERDA - EZKERRA: LA IZQUIERDA PLURAL - EZKER ANITZA" "UDALBERRI - BILBAO EN COMÚN"

*8) IU splits

local iusplit "IULV" "IULV"


********************************************************************************
*Harmonize codes and compute shares at the local level
*These  data are at the party by election and municipality, but we want to work
*with a municipality by election panel, so have to create variables accordingly
*and then reshape the dataset
foreach party in pnv ea pnvea pp psoe iu iusplit{
dis "`party'"
gen share_`party'_aux=0



foreach name in ``party''{
dis "`name'"

local a "`name'"



replace share_`party'_aux=votos_candi/(acandi+blancs+nuls) if denominacion==`"`a'"'

replace party="`party'" if denominacion==`"`a'"'
}
egen share_`party'=max(share_`party'), by(codi_mun codi_pro year tipo)
drop share_`party'_aux
}
********************************************************************************


*9) Other parties
*This makes sure denominations with special characters are picked up
gen auxupyd=strpos(denominacion, "N PROGRESO Y DEMOCRACIA") > 0
replace denominacion="UPyD" if auxupyd==1
drop auxupyd

local aralar "ARALAR" "ARALAR" "PARTIDO POLITICO ARALAR"  "ARALAR EZKERBATUA BERDEAK" "ARALAR-ZUTIK"
local upyd  "UPyD" "UPyD" "UPYD" "UNIÓN PROGRESO Y DEMOCRACIA" "UPD" "UNION PROGRESO Y DEMOCRACIA"
local batzarre "BATZARRE" "BATZARRE" "AMAIA-BATZARRE" "BATZARRE ASAMBLEA DE IZQUIERDAS DE BURLADA" "BATZARRE-ASAMBLEA DE IZQUIERDAS" "ACCION MUNICIPAL OBRERA-BATZARRE"
local cis "CIUDADANOS-PARTIDO DE LA CIUDADANIA" "CIUDADANOS-PARTIDO DE LA CIUDADANIA" "CIUDADANOS-PARTIDO DE LA CIUDADANÍA" "CIUDADANOS, PARTIDO DE LA CIUDADANIA. C's" "CS"
local podemos "PODEMOS" "PODEMOS" "PODEMOS-AHAL DUGU" "GANEMOS"
local nabai "NAFARROA BAI" "NAFARROA BAI""NABAI2011" "Nafarroa Bai 2011" "NABAI"
local zutik  "ZUTIK" "ZUTIK"
local ee "EE" "EE"
local ucd "Unión de Centro Democrático" "Unión de Centro Democrático"
local cds "CDS" "CDS" "CENTRO DEMOCRATICO Y SOCIAL"  "CENTRO DEMOCRÁTICO Y SOCIAL"
local ual "UAL" "UAL" "UNIDAD ALAVESA" 
local equo "EQUO" "EQUO" "EQUO-PUM+J"
local verdes "BERDEAK-LOS VERDES" "BERDEAK-LOS VERDES"  "BERDEAK - GRUPO VERDE" "BERDEAK - LOS VERDES (C.E. LV-IZQ. DE LOS PUEBLOS)" /*
*/ "BERDEAK - VERDES" "BERDEAK-EUROPAR TALDE BERDEA-LOS VERDES-GRUPO VERDE EUROPEO" "BERDEAK-EUROPEAN GREENS DE MUTRIKU" "BERDEAK-GRUPO VERDE EUROPEO" /*
*/ "BERDEAK-LOS VERDES" "BERDEAK-LOS VERDES O LOS VERDES-BERDEAK" "BERDEAKLV"
local cdn "CDN" "CDN"


foreach party in  aralar upyd batzarre cis podemos nabai zutik ee ucd cds ual equo verdes cdn{
dis "`party'"
gen share_`party'_aux=0



foreach name in ``party''{
dis "`name'"

local a "`name'"



replace share_`party'_aux=votos_candi/(acandi+blancs+nuls) if denominacion==`"`a'"'

replace party="`party'" if denominacion==`"`a'"'
}
egen share_`party'=max(share_`party'), by(codi_mun codi_pro year tipo)
drop share_`party'_aux
}




egen share_batasuna_aux=max(batasuna), by(tipo codi_mun codi_pro year)
replace batasuna=share_batasuna_aux
drop share_batasuna_aux

********************************************************************************

 
**********************RESHAPE AT THE MUNICIPALITY LEVEL*************************
*we have reshaped by creating variables for all parties, now every observation
*within a municipality by election is redundant, so we just keep one of them 
bys tipo codi_mun codi_pro year: gen num=_n
keep if num==1
drop denominacion siglas codi_candi votos_candi conce_candi cabecera_*

gen bat_share=batasuna/(acandi+blancs+nuls)
gen bat_call_share=(batasuna+nuls)/(acandi+blancs+nuls)

save global_dta.dta, replace
********************************************************************************



**Create auxiliary file with strings and municipality codes,
**useful to merge other files later****
 
clear all

import excel "codis_mun.xls", sheet("dic15") cellrange(A2:D8121) firstrow
rename CPRO codi_pro
destring codi_pro, replace
rename CMUN codi_mun
destring codi_mun, replace
drop DC
rename NOMBRE municipio

keep codi_pro codi_mun municipio
*Basque provinces
keep if codi_pro==1 |codi_pro==20 |codi_pro==48 

replace municipio=strupper(municipio)
sort codi_pro codi_mun
save codis_mun.dta, replace


 

