

*This takes the global terrorism database for Spain and cleans it to compute
*ETA attacks in the 10 years pre-ban, across municipalities
clear all

set more off

cd ${basedir}

*Take the global terrorism database for Spain

use "Data/gtd_spain_stata13.dta"

bys gname: gen num=_N
*keep ETA attacks, ETA identifier is num=1975
keep if num==1975
drop num

*keep attacks in the Basque Country
local locations1 `" "Alava" "Basque Country" "Basque Country (Administration Region)" "'
local locations2 `" "Basque Country (Administration Region)" "Basque Country (Autonomous Community)" "Basque Country (Autonomous community)" "'
local locations3 `" "Bilbao" "Biscay" "Gipuzcoa" "Guipuzcoa" "Navarre" "Vizcaya" "'

*Drop if not possible to identify the place where the attack took place
gen aux=.
forval z=1/3{
foreach list in `locations`z''{
replace aux=1 if provstat=="`list'"
}
}

keep if aux==1
drop if city=="Vizcaya district" | city=="Unknown"

gen a=1
egen attacks=sum(a), by(iyear)

rename iyear year


sort year

*Harmonize names, to merge with municipality codes
*also in some cases the database reports neighborhood rather than municipality
*also in some cases, attacks in Spanish big cities have been mistakenly labeled
*as taking place in the Basque Country, and they are dropped
gen name=""
replace name="Abadiño" if city=="Abadiano"
replace name="Azpeitia" if city=="Aginaga"
replace name="Getxo" if city=="Algorta"
replace name="Amorebieta-Etxano" if city=="Amorebieta"
replace name="Antzuola" if city=="Anzuola"
replace name="Huarte/Uharte" if city=="Aralar"
replace name="Asparrena" if city=="Araya"
replace name="Arrasate/Mondragón" if city=="Arrasate"
replace name="Arróniz" if city=="Arroniz"
replace name="Bilbao" if city=="Artxanda"
replace name="Azkoitia" if city=="Azcoitia"
replace name="Larraun" if city=="Azpiroz"
replace name="Barañain" if city=="Barañain"
replace name="Zeanuri" if city=="Barazar"
replace name="Barrika" if city=="Barrica"
replace name="Labastida/Bastida" if city=="Bastida"
replace name="Isaba/Izaba" if city=="Belagua"
replace name="Berastegi" if city=="Berastegui"
replace name="Beriáin" if city=="Beriain"
replace name="Buñuel" if city=="Bunuel"
replace name="Auritz/Burguete" if city=="Burguete"
replace name="Burlada/Burlata" if city=="Burlada"
replace name="Castejón" if city=="Castejon"
replace name="Zegama" if city=="Cegama"
drop if city=="Churriana"
*Churriana is in Malaga
replace name="Zizur Mayor/Zizur Nagusia" if city=="Cizur Mayor"
replace name="Zizurkil" if city=="Cizurquil"
replace name="Bilbao" if city=="Deusto"
replace name="Donostia-San Sebastián" if city=="Donostia-San Sebastian" | city=="San Sebastian" | city=="San Sabastian" | city=="Eguia"
replace name="Etxarri-Aranatz" if city=="Echarri-Aranaz"
replace name="Donostia-San Sebastián" if city=="Egia"
replace name="Oiartzun" if city=="Elizalde"
replace name="Iruraiz-Gauna" if city=="Erenchun"
replace name="Galar" if city=="Esquiroz"
replace name="Estella/Lizarra" if city=="Estella"
replace name="Hondarribia" if city=="Fuenterrabia"
replace name="Galdakao" if city=="Galdacano"
replace name="Abanto y Ciérvana-Abanto Zierbena" if city=="Gallarta"
replace name="Gorliz" if city=="Gorliz-Elexalde"
replace name="Gernika-Lumo" if city=="Guernica"
replace name="Getaria" if city=="Guetaria"
replace name="Zuia" if city=="Guillerna"
replace name="Itsasondo" if city=="Isasondo"
replace name="Urkabustaiz" if city=="Izarra"
replace name="Laudio/Llodio" if city=="LLodio" | city=="Llodio"
replace name="Valle de Trápaga-Trapagaran" if city=="La Arboleda"
replace name="Getxo" if city=="Las Arenas"
replace name="Lasarte-Oria" if city=="Lasarte"
replace name="Lekunberri" if city=="Lecumberri"
replace name="Legazpi" if city=="Legazpia"
replace name="Legutio" if city=="Legutiano"
replace name="Lemoa" if city=="Lemorieta"
drop if city=="Logrono"
replace name="Donostia-San Sebastián" if city=="Loiola" | city=="Monte Ulia"
replace name="Arcos, Los" if city=="Los Arcos"
replace name="Ayala/Aiara" if city=="Luyando"
replace name="Markina-Xemein" if city=="Marquina"
replace name="Ugao-Miraballes" if city=="Miravalles"
replace name="Zuia" if city=="Murguia"
replace name="Ochagavía/Otsagabia" if city=="Ochagavia"
replace name="Olite/Erriberri" if city=="Olite"
replace name="Oñati" if city=="Onate"
replace name="Oiartzun" if city=="Oyarzun"
replace name="Pamplona/Iruña" if city=="Pamplona"
replace name="Pasaia" if city=="Pasajes" | city=="Pasajes de San Juan" | city=="Pasajes de San Pedro"
replace name="Puente la Reina/Gares" if city=="Puente La Reina"
replace name="Errenteria" if city=="Renteria"
replace name="Ribera Baja/Erribera Beitia" if city=="Ribabellosa"
replace name="Salvatierra/Agurain" if city=="Salvatierra"
replace name="Muskiz" if city=="San Julian De Musques"
replace name="Sangüesa/Zangoza" if city=="Sanguesa"
drop if city=="Santander"
*Santander is in Cantabria
replace name="Santurtzi" if city=="Santurce"
replace name="Güeñes" if city=="Sodupe"
replace name="Urdazubi/Urdax" if city=="Urdax"
replace name="Lemoiz" if city=="Urizar De Lemoniz"
replace name="Bedia" if city=="Vedia-Elejalde"
replace name="Bera" if city=="Vera De Bidasoa"
replace name="Bergara" if city=="Vergara"
replace name="Ordizia" if city=="Villafranca De Ordizia" | city=="Villafranca de Ordizia"
replace name="Legutio" if city=="Villarreal De Alava" | city=="Leguitano"
replace name="Vitoria-Gasteiz" if city=="Vitoria"
drop if city=="Zaragoza"
*Zaragoza is in Aragon
replace name="Güeñes" if city=="Zaramillo"
replace name="Zarautz" if city=="Zarauz"
replace name="Iza/Itza" if city=="Zuasti"
replace name="Bermeo" if city=="bermeo"
replace name="Bilbao" if city=="bilbao"
replace name="Getaria" if city=="guetaria"
replace name="Hernani" if city=="hernani"
replace name="Irun" if city=="irun"
replace name="Pamplona/Iruña" if city=="pamplona"
replace name="Pasaia" if city=="pasajes"
replace name="Portugalete" if city=="portugalete"
replace name="Altsasu/Alsasua" if city=="Alsasua"
replace name="Barañain" if city=="Baranain"

rename name nom
replace nom=city if nom==""
replace nom=trim(nom)
sort nom
save  Data/terrorattacks_eta_data.dta, replace


*Merge with local indicators, create variable for attacks in the 10 years pre-ban


clear
use Data/codis_mun_access16.dta

sort nom

merge 1:m nom using  Data/terrorattacks_eta_data

drop if _merge!=3
*Basque provinces
keep if codi_pro=="01" | codi_pro=="20" | codi_pro=="48"

*These are actually deaths of ETA members, not ETA attacks
drop if targtype1_txt=="Terrorists/Non-State Militia"

rename iday day
rename imonth month
drop a
gen all=1

foreach var in all{
gen a=`var' if year>1996 & year<2007
egen `var'_pre10=sum(a), by(ident)
drop a
}
bys ident: gen n=_n
keep if n==1
keep all_pre10 ident

destring ident, replace
sort ident

save Data/terror_tomerge.dta, replace

erase Data/terrorattacks_eta_data.dta
