

**********This produces the ready_to_output file, which merges a number*********
*******of previously cleaned data sources and creates relevant variables******** 
 

clear all
set more off
cd ${basedir}/Data
clear 
use global_dta.dta, replace

*keep local elections in the Basque Country
keep if tipo==4  

*Add links variables to do IV
sort codi_mun codi_pro
merge codi_mun codi_pro using police.dta

gen turnout=(acandi+blancs+nuls)/cens
gen nuls_share=nuls/(acandi+blancs+nuls)

gen bat_nn_share=bat_call_share-nuls_share
replace bat_call_share=(batasuna+nuls)/(acandi+blancs+nuls)

*Total number of seats changes discontinuosly with municipality size
*Useful to input the hypothetical number of clean/linked candidates in case of missing value
gen total_conce=3 if cens<100
replace total_conce=5 if cens<250 & total_conce==.
replace total_conce=7 if cens<1000 & total_conce==.
replace total_conce=9 if cens<2000 & total_conce==.
replace total_conce=11 if cens<5000 & total_conce==.
replace total_conce=13 if cens<10000 & total_conce==.
replace total_conce=17 if cens<20000 & total_conce==.
replace total_conce=21 if cens<50000 & total_conce==.
replace total_conce=25 if cens<100000 & total_conce==.
replace total_conce=27 if cens<300000 & total_conce==.
replace total_conce=29 if cens<500000 & total_conce==.

*For every variable, we want to have the yearly record available for every observation
forval z=1987(4)2015{
gen bat_share_`z'aux=bat_share if year==`z'
egen bat_share_`z'=max(bat_share_`z'aux), by(codi_mun codi_pro)
gen bat_call_share_`z'aux=bat_call_share if year==`z'
egen bat_call_share_`z'=max(bat_call_share_`z'aux), by(codi_mun codi_pro)

gen bat_present_`z'=.
replace bat_present_`z'=1 if bat_share_`z'!=0  
replace bat_present_`z'=0 if bat_share_`z'==0

gen total_conce_`z'aux=total_conce if year==`z'
egen total_conce_`z'=max(total_conce_`z'aux), by(codi_mun codi_pro)

gen share_ea_`z'aux=share_ea if year==`z'
egen share_ea_`z'=max(share_ea_`z'aux), by(codi_mun codi_pro)

gen share_pnv_`z'aux=share_pnv if year==`z'
egen share_pnv_`z'=max(share_pnv_`z'aux), by(codi_mun codi_pro)

gen share_pnvea_`z'aux=share_pnvea if year==`z'
egen share_pnvea_`z'=max(share_pnvea_`z'aux), by(codi_mun codi_pro)

gen ea_present_`z'=.
replace ea_present_`z'=1 if share_ea_`z'!=0
replace ea_present_`z'=1 if share_ea_`z'==0

gen pnvea_present_`z'=.
replace pnvea_present_`z'=1 if share_pnvea_`z'!=0
replace pnvea_present_`z'=0 if share_pnvea_`z'==0

gen share_aralar_`z'aux=share_aralar if year==`z'
egen share_aralar_`z'=max(share_aralar_`z'aux), by(codi_mun codi_pro)

gen share_psoe_`z'aux=share_psoe if year==`z'
egen share_psoe_`z'=max(share_psoe_`z'aux), by(codi_mun codi_pro)

gen share_pp_`z'aux=share_pp if year==`z'
egen share_pp_`z'=max(share_pp_`z'aux), by(codi_mun codi_pro)

gen share_iu_`z'aux=share_iu if year==`z'
egen share_iu_`z'=max(share_iu_`z'aux), by(codi_mun codi_pro)

drop bat_share_`z'aux bat_call_share_`z'aux  total_conce_`z'aux share_pnv_`z'aux share_ea_`z'aux share_pnvea_`z'aux share_aralar_`z'aux
}

*In Otxandio, EAE - ANV was not banned, but they withdrew just before the election. Hence, it is recorded as no ban. 
replace bat_present_2007=1 if municipio=="OTXANDIO"
gen bat_present=0
replace bat_present=1 if bat_share!=0
replace bat_present=1 if municipio=="OTXANDIO" & year==2007


********IF NO DATA ON LINKS AND PRESENT, WE ASSUME THEY WERE FULLY CLEAN********

replace csc=-2 if no_data==1 & bat_present_2007==1
replace dum_three=0 if no_data==1 & bat_present_2007==1
replace numcandis=0 if no_data==1 & bat_present_2007==1
replace dum_elected=0 if no_data==1 & bat_present_2007==1
replace treatment=0 if no_data==1 & bat_present_2007==1


********IF NO DATA AND BANNED, WE ASSUME THEY WERE ABOVE THE THRESHOLDS*********
*All this will be relaxed when looking at estimates excluding these observations

replace csc=total_conce_2007-2 if no_data==1 & bat_present_2007==0
replace dum_three=0 if csc<=0 & no_data==1 & bat_present_2007==0
replace dum_three=1 if no_data==1 & csc>=1 & bat_present_2007==0
replace dum_elected=1 if no_data==1 & bat_present_2007==0
replace treatment=dum_three*dum_elected if no_data==1 & bat_present_2007==0

********************************************************************************

gen post=0
replace post=1 if year>=2011

gen treatpost2007=bat_present_2007*post
gen dum_elected_post=dum_elected*post
gen dum_three_post=dum_three*post
gen treatment_post=treatment*post
gen numcandis_post=numcandis*post
gen csc_post=csc*post
gen csc2_post=csc2*post
egen ident=group(codi_mun codi_pro)
replace no_data=0 if bat_present_2007==1

egen meanpre=rmean(bat_call_share_1999 bat_call_share_1995 bat_call_share_1991 bat_call_share_1987)
egen meanpost=rmean(bat_call_share_2011 bat_call_share_2015)
gen withindif=meanpost-meanpre
 

egen groupleg=group(bat_present_1999 bat_present_1995 bat_present_1991 bat_present_1987)

save ready_to_output.dta, replace

capture saveold ready_to_output.dta, version(13)  replace
 
 
********************************************************************************
*This saves an aux. file w/ variables with electoral results in local elections*
*This is useful to merge with data on regional elections and street violence****
********************************************************************************
clear

use ready_to_output.dta

bys ident: gen sident=_n
keep if sident==1

local varstokeep  bat_call_share* bat_present* bat_share* share_ea* share_pnv*  

local policevars municipio mesa_nacional aub herzer aukera sumcount sumcount_elected numcandis three three_elected three_weak three_elected_weak sumcount_fiscal sumcount_elected_fiscal weak_fiscal terror no_data treatment dum_three dum_elected csc csc2 csc3 

keep ident codi_pro codi_mun `varstokeep' `policevars'

foreach oldname of varlist `varstokeep' {
rename `oldname' m_`oldname'
}
drop m_bat_call_share  m_bat_present m_bat_share m_share_pnv m_share_ea m_share_pnvea 


sort codi_mun codi_pro

save aux_regional.dta, replace
