

**************This produces all the output on local election results************


clear 
set more off 
set matsize 800

cd ${basedir}

use Data/ready_to_output.dta

gen ident_aux=codi_pro*1000+codi_mun
replace codi_pro=0
replace treatpost2007=-treatpost2007
gen platreatpost2007=-bat_present_2007*(year>=1999)

gen all_nationalists=bat_share+share_ea+share_pnv+share_pnvea+share_aralar+nuls_share
 

***************************FIGURES 1 TO 7***************************************
foreach var in turnout bat_call_share nuls_share  bat_nn_share bat_present share_aralar all_nationalists{
gen `var'aux=`var'*100  
egen mean`var'=mean(`var'aux), by(year)
egen mean`var'by=mean(`var'aux), by(year bat_present_2007)
}
gen bat_present_2007auxc=(bat_present_2007==0)


gen turnout_aux=turnout*100

binscatter turnout_aux year, by(bat_present_2007auxc) xline(2007) xlabel(1987(4)2015)  linetype(connect) ytitle("Percentage")  xtitle("Election year") /*
*/  legend(  order( 1 "Turnout, Legal in 2007" 2 "Turnout, Ban in 2007")   size(small) )  ylabel(55(10)75) aspectratio(.4)  graphregion(color(white)) bgcolor(white)   $symbolscolors
quietly graph export "paper/turnout_plot.eps", as(eps) replace
drop turnout_aux

gen nuls_share_aux=nuls_share*100

binscatter nuls_share_aux year, by(bat_present_2007auxc) xline(2007) xlabel(1987(4)2015)  linetype(connect) ytitle("Percentage")  xtitle("Election year")   note("Note: Null Vote as a % of Total Votes Cast", pos(6)) /*
*/  legend(  order( 1 "Null Vote, Legal in 2007" 2 "Null Vote, Ban in 2007")   size(small) )  aspectratio(.4)  graphregion(color(white)) bgcolor(white)   $symbolscolors
quietly graph export "paper/nuls_plot.eps", as(eps) replace
drop nuls_share_aux



gen bat_nn_share_aux=bat_nn_share*100

binscatter bat_nn_share_aux year, by(bat_present_2007auxc) xline(2007) xlabel(1987(4)2015)  linetype(connect) ytitle("Percentage")  ylabel(0(10)50)  xtitle("Election year")   note("Note: Batasuna Vote as a % of total votes", pos(6)) /*
*/  legend(  order( 1 "Batasuna Vote, Legal in 2007" 2 "Batasuna Vote,Ban in 2007")   size(small) )  aspectratio(.4)  graphregion(color(white)) bgcolor(white)   $symbolscolors
quietly graph export "paper/bat_plot.eps", as(eps) replace

drop bat_nn_share_aux

replace all_nationalists=all_nationalists*100

binscatter all_nationalists year, by(bat_present_2007auxc) xline(2007) xlabel(1987(4)2015)  linetype(connect) ytitle("Percentage")  xtitle("Election year")   note("Note: Sum of Batasuna, Null, EA, PNV-EA, PNV, Aralar, as a % of total votes", span pos(6))/*
*/  legend( order(  1  "Basque Nationalist Vote, Legal in 2007" 2 "Basque Nationalist Vote, Ban in 2007" ) rows(2) size(small) )   aspectratio(.4)  graphregion(color(white)) bgcolor(white)   $symbolscolors
quietly graph export "paper/all_nationalists.eps", as(eps) replace


gen spanish_left=(share_psoe+share_iu+share_iusplit+share_podemos+share_equo+share_verdes)*100
 
binscatter spanish_left year, by(bat_present_2007auxc) xline(2007) xlabel(1987(4)2015) linetype(connect) ytitle("Percentage")  xtitle("Election year")   note("Note: Sum of PSOE, IU, Podemos, Equo, Verdes, as % of total votes", span pos(6))/*
*/  legend( order( 1  "Federal Left, Legal in 2007" 2  "Federal Left, Ban in 2007" ) rows(1) size(small) )   aspectratio(.4)  graphregion(color(white)) bgcolor(white)   $symbolscolors
quietly graph export "paper/supportspanish_left_did.eps", as(eps) replace


gen spanish_right=(share_pp+share_cis+share_upyd+share_cds+share_ual)*100	

binscatter spanish_right year, by(bat_present_2007auxc) xline(2007) xlabel(1987(4)2015) ylabel(0(2)14) linetype(connect) ytitle("Percentage")  xtitle("Election year")   note("Note: Sum of PP, C's, UPyD, CDS, UA, as % of total votes", span pos(6))/*
*/  legend( order( 1  "Federal Right, Legal in 2007" 2  "Federal Right, Ban in 2007" ) rows(1) size(small) )   aspectratio(.4)  graphregion(color(white)) bgcolor(white)   $symbolscolors
quietly graph export "paper/supportspanish_right_did.eps", as(eps) replace

 

gen other_local=100-all_nationalists-spanish_right-spanish_left-blancs*100/(blancs+acandi+nuls)

binscatter other_local year, by(bat_present_2007auxc) xline(2007) xlabel(1987(4)2015) ylabel(10(2)20)  linetype(connect) ytitle("Percentage")  xtitle("Election year")/*
*/  legend( order( 1 "Other Local Parties, Legal in 2007"  2   "Other Local Parties, Ban in 2007" ) rows(1) size(small) )   aspectratio(.4)  graphregion(color(white)) bgcolor(white)   $symbolscolors
quietly graph export "paper/supportothers_did.eps", as(eps) replace

********************************************************************************


 

********************************************************************************
**********************BASELINE SPECIFICATION CONTROLS***************************
gen cens2=cens^2
gen cens3=cens^3
 
global controlsfe   year#groupleg i.year
global democontrols cens cens2 cens3
global if if year!=2007 

save Data/aux_heterogeneity.dta, replace
 

***************************TABLES 1 AND A2(PLACEBO)***************************** 
foreach outcome in all_nationalists spanish_left spanish_right other_local{
replace `outcome'=`outcome'/100
}
eststo clear
xtset ident
local i=0

foreach outcome in turnout nuls_share bat_call_share all_nationalists spanish_left spanish_right other_local{
*TABLE 1
local i=`i'+1
quietly xtreg `outcome' treatpost2007 $controlsfe $democontrols $if, fe cluster(ident)
est sto t1_`i'
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace 
*TABLE A2
quietly xtreg `outcome' treatpost2007 platreatpost2007 $controlsfe $democontrols $if, fe cluster(ident)
est sto t1p_`i'
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace 
}


*TABLE 1
 esttab t1_1 t1_2 t1_3 t1_4 using paper/taula1_1.tex,  se keep(treatpost2007) /*
*/ tex gaps  coeflabels(treatpost2007 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$" ) /*
*/  nomtitles mgroups( "Turnout"  "Null Votes"  "\makecell{Batasuna\\Support}"  "\makecell{All Basque\\ Nationalists}", pattern(1 1 1 1  ) prefix(\multicolumn{@span}{c}{) suffix(}) span  )   /*
*/   s( MuniFE PBPYearFE   N N_clust, label(  "\addlinespace[1ex] Municipality FE" "Pre-ban presence $\times$ election FE" "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{5}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses. /*
*/ Support for Batasuna is measured as the sum of Batasuna votes and Null votes, as a fraction of total votes. Nationalist support /*
*/ is the sum of Support for Batasuna, PNV, EA, PNV-EA, and Aralar, as a fraction of total votes. /*
*/ In all regressions, 2007 is excluded from the sample. All regressions control for a cubic in municipality size.}\\ /*
*/ \end{tabular}} ) replace


 esttab t1_5 t1_6 t1_7   using paper/taula1_2.tex,  se keep(treatpost2007) /*
*/ tex gaps  coeflabels(treatpost2007 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$" ) /*
*/  nomtitles mgroups( "Federal Left" "Federal Right"  "\makecell{Other local \\parties}", pattern(1 1 1   ) prefix(\multicolumn{@span}{c}{) suffix(}) span  )   /*
*/   s( MuniFE PBPYearFE   N N_clust, label(  "\addlinespace[1ex] Municipality FE" "Pre-ban presence $\times$ election FE" "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{4}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses./*
*/ Federal left is the sum of PSOE, IU, Podemos, Los Verdes, and Equo, as a fraction of total votes. /*
*/ Federal Right is the sum of PP, Ciudadanos, Unidad Alavesa, Centro Democr\'{a}tico y Social, and UPyD. Other local parties are votes that are neither for Nationalists, Federal Left or Federal Right. /*
*/ In all regressions, 2007 is excluded from the sample. All regressions control for a cubic in municipality size.}\\ /*
*/ \end{tabular}} ) replace

*TABLE A2 (PLACEBO)
 esttab t1p_1 t1p_2 t1p_3 t1p_4 using paper/taulap1_1.tex,  se keep(treatpost2007 platreatpost2007) /*
*/ tex gaps  coeflabels(treatpost2007 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$" platreatpost2007 "\addlinespace[1ex] \$I(\text{Post 1995}) \times I(\text{Ban in 2007})$" ) /*
*/  nomtitles mgroups( "Turnout"  "Null Votes"  "\makecell{Batasuna\\Support}"  "\makecell{All Basque\\ Nationalists}", pattern(1 1 1 1  ) prefix(\multicolumn{@span}{c}{) suffix(}) span  )   /*
*/   s( MuniFE PBPYearFE   N N_clust, label(  "\addlinespace[1ex] Municipality FE" "Pre-ban presence $\times$ election FE" "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{5}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses. /*
*/The placebo treatment is equal to zero in 1987, 1991, 1995, and equal to the treatment from 1999 onwards. Support for Batasuna is measured as the sum of Batasuna votes and Null votes, as a fraction of total votes. Nationalist support /*
*/ is the sum of Support for Batasuna, PNV, EA, PNV-EA, and Aralar, as a fraction of total votes. /*
*/ In all regressions, 2007 is excluded from the sample. All regressions control for a cubic in municipality size.}\\ /*
*/ \end{tabular}} ) replace


 esttab t1p_5 t1p_6 t1p_7   using paper/taulap1_2.tex,  se keep(treatpost2007 platreatpost2007) /*
*/ tex gaps  coeflabels(treatpost2007 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$" platreatpost2007 "\addlinespace[1ex] \$I(\text{Post 1995}) \times I(\text{Ban in 2007})$") /*
*/  nomtitles mgroups( "Federal Left" "Federal Right"  "\makecell{Other local \\parties}", pattern(1 1 1   ) prefix(\multicolumn{@span}{c}{) suffix(}) span  )   /*
*/   s( MuniFE PBPYearFE   N N_clust, label(  "\addlinespace[1ex] Municipality FE" "Pre-ban presence $\times$ election FE" "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{4}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses./*
*/ The placebo treatment is equal to zero in 1987, 1991, 1995, and equal to the treatment from 1999 onwards. Federal left is the sum of PSOE, IU, Podemos, Los Verdes, and Equo, as a fraction of total votes. /*
*/ Federal Right is the sum of PP, Ciudadanos, Unidad Alavesa, Centro Democr\'{a}tico y Social, and UPyD. Other local parties are votes that are neither for Nationalists, Federal Left or Federal Right. /*
*/ In all regressions, 2007 is excluded from the sample. All regressions control for a cubic in municipality size.}\\ /*
*/ \end{tabular}} ) replace


 
*********************************TABLE 2****************************************


*Average pre-ban share, by post indicator
egen rmean_pre_post=rmean(bat_call_share_1987 bat_call_share_1991 bat_call_share_1995 bat_call_share_1999 bat_call_share_2003)
gen bat_call_share_pre_post=post*rmean_pre_post
*Ad-interim support, by post indicator
gen bat_call_share_post_post=post*(bat_call_share_2007)
 

eststo clear
*1-Accounting for pre-ban support
global outc1 bat_call_share
quietly xtreg $outc1 treatpost2007 bat_call_share_pre_post $controlsfe $democontrols $if, fe cluster(ident)
est sto t1c1
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local Prepostsup "$\checkmark$" , replace

*2-Accounting for ad-interim
quietly xtreg $outc1 treatpost2007 bat_call_share_pre_post bat_call_share_post_post $controlsfe $democontrols $if, fe cluster(ident)
est sto t1c2
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local Prepostsup "$\checkmark$" , replace
estadd local Postpostsup "$\checkmark$" , replace
 

esttab t1c1 t1c2  using paper/tab_mec1.tex,  se keep(treatpost2007) /*
*/ tex gaps  coeflabels(treatpost2007 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$" ) /*
*/  nomtitles mgroups( "Batasuna Support" , pattern(1 0   ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})   )   /*
*/   s( MuniFE PBPYearFE Prepostsup Postpostsup   N N_clust, label(  "\addlinespace[1ex] Municipality FE" "Pre-ban presence $\times$ election FE" /*
*/ "\$I(\text{Post 2007}) \times \text{Pre-ban Support}$" "\$I(\text{Post 2007}) \times \text{Support in 2007}$"   "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{3}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses./*
*/ Support for Batasuna is measured as the sum of Batasuna votes and Null votes./* 
*/ Pre-ban support is the 1987-2003 average. /*
*/ In all regressions, 2007 is excluded from the sample. All regressions control for a cubic in municipality size.}\\ /*
*/ \end{tabular}} ) replace

********************************************************************************
 
**********************Robustness Null votes*************************************
gen platreatpost2003=(year>=2003)*treatment

eststo clear
xtset ident
local i=0
foreach outcome in nuls_share{
local i=`i'+1

quietly xtreg `outcome' platreatpost2003 i.year $democontrols $if & year<=2003, fe cluster(ident)
est sto t1_`i'
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local Sample "Until 2003" , replace
 
quietly xtreg `outcome' platreatpost2003 $controlsfe $democontrols $if & year<=2003, fe cluster(ident)
est sto t2_`i'
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace 
estadd local Sample "Until 2003" , replace
}

quietly xtreg bat_call_share treatpost2007 platreatpost2003 $controlsfe $democontrols $if, fe cluster(ident)
est sto t3_`i'
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace 
estadd local Sample "Full" , replace


 esttab t1_1 t2_1 t3_1 using paper/taula_r_1.tex,  se keep(treatpost2007 platreatpost2003) /*
*/ tex gaps  coeflabels(treatpost2007 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$" platreatpost2003 "\addlinespace[1ex] \$I(\text{Year=2003}) \times I(\text{Ban in 2007})$" ) /*
*/  nomtitles mgroups( "Null Votes"  "Null Votes" "Batasuna Support", pattern(1 1 1  ) prefix(\multicolumn{@span}{c}{) suffix(}) span  )   /*
*/   s( MuniFE YearFE PBPYearFE Sample  N N_clust, label(  "\addlinespace[1ex] Municipality FE" "Election FE" "Pre-ban presence $\times$ election FE" "Sample" "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{4}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses./*
*/ In all regressions, 2007 is excluded from the sample. All regressions control for a cubic in municipality size.}\\ /*
*/ \end{tabular}} ) replace


******************************************************************************** 

*************************Robustness ebalance************************************
eststo clear 
gen meancens_preaux=cens if year<2007
egen meancens_pre=mean(meancens_preaux), by(ident)


ebalance bat_present_2007 bat_present_1999 bat_present_1995 bat_present_1991 bat_present_1987 bat_call_share_2003 bat_call_share_1999 bat_call_share_1995 bat_call_share_1991 bat_call_share_1987 /*
*/share_ea_2003 share_ea_1999 share_ea_1995 share_ea_1991 share_ea_1987 share_pnv_2003 share_pnv_1999 share_pnv_1995 share_pnv_1991 share_pnv_1987/*
*/ share_pnvea_2003 share_pnvea_1999 share_pnvea_1995 share_pnvea_1991 share_pnvea_1987 share_iu_2003 share_iu_1999 share_iu_1995 share_iu_1991 /*
*/ share_pp_2003 share_pp_1999 share_pp_1995 share_pp_1991 share_psoe_2003 share_psoe_1999 share_psoe_1995 share_psoe_1991 share_aralar_2003 meancens_pre  if year==2007, g(w1)

egen mw1=max(w1), by(ident)

xtreg bat_call_share treatpost2007 $controlsfe $democontrols $if [aweight=mw1], fe cluster(ident)
est sto t1 
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace 
xtreg all_nationalists treatpost2007 $controlsfe $democontrols $if [aweight=mw1], fe cluster(ident)
est sto t2
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace 


 esttab t1 t2  using paper/taula_eb.tex,  se keep(treatpost2007) /*
*/ tex gaps  coeflabels(treatpost2007 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$" ) /*
*/  nomtitles mgroups(  "\makecell{Batasuna\\Support}"  "\makecell{All Basque\\ Nationalists}", pattern(1 1  ) prefix(\multicolumn{@span}{c}{) suffix(}) span  )   /*
*/   s( MuniFE PBPYearFE   N N_clust, label(  "\addlinespace[1ex] Municipality FE" "Pre-ban presence $\times$ election FE" "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{3}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses. /*
*/ Support for Batasuna is measured as the sum of Batasuna votes and Null votes, as a fraction of total votes. Nationalist support /*
*/ is the sum of Support for Batasuna, PNV, EA, PNV-EA, and Aralar, as a fraction of total votes. /*
*/ In all regressions, 2007 is excluded from the sample. All regressions control for a cubic in municipality size. /*
*/ Estimates weighted according to entropy balance weights, as described in the text.}\\ /*
*/ \end{tabular}} ) replace
 
drop w1 mw1  
 
******************************************************************************** 
 
 
 
 
 
 
 

 
 
 
 
************************TABLE 3: CORRELATES OF VOTE LOSS************************
drop _merge
rename ident ident_temp
rename ident_aux ident
sort ident
merge ident using Data/terror_tomerge.dta

rename ident ident_temp2
rename ident_temp ident
 
*Log of terror attacks in the last 10 years  
replace all_pre10=0 if all_pre10==.
gen log_all_pre10=log(1+all_pre10)


gen cens2007aux=cens if year==2007
egen cens2007=max(cens2007aux), by(ident)
gen logcens2007=log(cens2007) 

 
*Close election in 2010 between other nationalists and spanish parties
gen other_nationalists=share_pnv+share_ea+share_pnvea+share_aralar
gen share_pp_psoe=share_pp+share_psoe
gen all_spanish=spanish_left+spanish_right
foreach var in share_pp_psoe all_spanish other_nationalists{
gen aux`var'=`var' if year==1999
egen `var'99=max(aux`var'), by(ident)
drop aux`var'

gen aux`var'=`var' if year==2003
egen `var'03=max(aux`var'), by(ident)

drop aux`var'
gen aux`var'=`var' if year<=2003
egen `var'pre=mean(aux`var'), by(ident)
}

gen delta03aux=(all_spanish-other_nationalists) if year==2003
egen delta03=max(delta03aux), by(ident)
gen delta032=abs(delta03)
gen close=(delta032<.1)


*Rewrite treatment variable to avoid errors in interpreting the sign of interactions
gen ntreat2007=(bat_present_2007==0)*(year==2007)
gen newpost=(year>=2007)
gen newtreatpost2007=(bat_present_2007==0)*newpost 
 

 
*Demean variables to be interacted, for a better intercept interpretation 
foreach var in log_all_pre10 logcens2007 close bat_call_share_2003{
egen mean_`var'=mean(`var')
rename `var' raw_`var'
gen `var'=raw_`var'-mean_`var'
drop mean_`var'
}
 
 
eststo clear
quietly  reghdfe bat_call_share  newtreatpost2007    c.newtreatpost2007#c.log_all_pre10 c.newpost#c.log_all_pre10  c.newtreatpost2007#c.close   c.newpost#c.close c.newtreatpost2007#c.logcens2007 c.newpost#c.logcens2007 c.bat_call_share_2003#c.newtreatpost2007 c.bat_call_share_2003#c.newpost cens cens2 cens3 if year<=2007, absorb( year year#groupleg ident) vce(cluster ident) 

est sto corr_imm
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local closepost "$\checkmark$" , replace
estadd local terrorpost "$\checkmark$" , replace
estadd local popupost "$\checkmark$" , replace
estadd local bat2003treat "$\checkmark$" , replace
estadd local bat2003post "$\checkmark$" , replace
estadd local sample "Until 2007, included" , replace
quietly reghdfe bat_call_share  newtreatpost2007 c.newtreatpost2007#c.log_all_pre10 c.newpost#c.log_all_pre10  c.newtreatpost2007#c.close  c.newpost#c.close c.newtreatpost2007#c.logcens2007 c.newpost#c.logcens2007 c.bat_call_share_2003#c.newtreatpost2007 c.bat_call_share_2003#c.newpost cens cens2 cens3 if year!=2007, absorb( year year#groupleg ident) vce(cluster ident) 
est sto corr_post
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local closepost "$\checkmark$" , replace
estadd local terrorpost "$\checkmark$" , replace
estadd local popupost "$\checkmark$" , replace
estadd local bat2003treat "$\checkmark$" , replace
estadd local bat2003post "$\checkmark$" , replace
estadd local sample "Full (excluding 2007)" , replace


esttab corr_imm corr_post  using paper/tab_corr.tex,  se keep(newtreatpost2007  c.newtreatpost2007#c.log_all_pre10 c.newtreatpost2007#c.close c.newtreatpost2007#c.logcens2007 ) /*
*/ tex gaps  coeflabels(newtreatpost2007 "\addlinespace[1ex] \$I(\text{Year}\geq\text{2007}) \times I(\text{Ban in 2007})$" /*
*/  c.newtreatpost2007#c.log_all_pre10 "\addlinespace[1ex] \$I(\text{Year}\geq\text{2007}) \times I(\text{Ban in 2007}) \times ln(1+\#Terror Attacks)$" /*
*/  c.newtreatpost2007#c.close "\addlinespace[1ex] \$I(\text{Year}\geq\text{2007}) \times I(\text{Ban in 2007}) \times Close$"  /*
*/  c.newtreatpost2007#c.logcens2007 "\addlinespace[1ex] \$I(\text{Year}\geq\text{2007}) \times I(\text{Ban in 2007}) \times ln(Population\:\: in\:\: 2007)$" ) /*
*/  nomtitles mgroups( "Batasuna Support" , pattern(1 0   ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})  )   /*
*/   s(sample MuniFE PBPYearFE terrorpost closepost  popupost bat2003treat bat2003post N N_clust, label("\addlinespace[1ex] Sample" "Municipality FE" "Pre-ban presence $\times$ election FE" /*
*/  " \$I(\text{Year}\geq\text{2007}) \times ln(1+\#Terror Attacks)$" "\$I(\text{Year}\geq\text{2007}) \times Close$" "\$I(\text{Year}\geq\text{2007}) \times ln(Population\:\: in\:\: 2007)$" /*
*/ "\$I(\text{Year}\geq\text{2007}) \times Support\:\: in \:\:2003$" " \$I(\text{Year}\geq\text{2007}) \times I(\text{Ban in 2007}) \times Support\:\: in\:\: 2003$" /*
*/ "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{3}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses. /*
*/ All interacted variables are demeaned /*
*/ Support for Batasuna is measured as the sum of Batasuna votes and Null votes. /*
*/ \# Terror attacks is the number of ETA attacks in the municipality in the 10 years prior to the 2007 ban. /*
*/  Close is a dummy equal to one if in 2003, the  absolute difference in vote share between Federal and Basque parties was below 10\%.  Support in 2003 refers to support for Batasuna. /* 
*/  All regressions control for a cubic in municipality size.}\\ /*
*/ \end{tabular}} ) replace


**********************Descriptives, correlates of vote loss*********************

global corvars raw_log_all_pre10 raw_close raw_logcens2007 raw_bat_call_share_2003
label variable raw_log_all_pre10 "\hline \\ ln(1+\#Terror Attacks)"
label variable raw_close "[1em] Close"
label variable raw_logcens2007 "[1em] ln(Population in 2007)"
label variable raw_bat_call_share_2003 "[1em] Batasuna Support in 2003"


estpost tabstat	 $corvars if bat_present_2007==0 & year==2007,  ///
statistics(mean sd) columns(statistics) listwise
est store A
distinct ident if bat_present_2007==0 & year==2007
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $corvars if bat_present_2007==1 & year==2007,  ///
statistics(mean sd) columns(statistics) listwise
est store B
distinct ident if  bat_present_2007==1 & year==2007
estadd local clusters `r(ndistinct)' , replace 

estpost tabstat	 $corvars if   year==2007,  ///
statistics(mean sd) columns(statistics) listwise
est store C
distinct ident if   year==2007
estadd local clusters `r(ndistinct)' , replace 

 
esttab A B C  using paper/desc_cor.tex,  main(mean) aux(sd) unstack  nostar   label   /*
*/ tex nogaps  nonumbers   mtitles("Treated" "Control" "Total")   /*
*/ s(clusters ,  label("\hline \addlinespace[1ex] Municipalities" )) /* 
*/ prehead("{" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" "\begin{tabular}{l*{3}{c}}" "\hline\hline" "Variable Name	")/*
*/   nonotes postfoot(\hline\hline \multicolumn{4}{{p{\linewidth}}}{\footnotesize /*
*/  Treated: municipalities in which Batasuna  was banned in 2007.  Standard deviations in parentheses. Batasuna support is the  sum of Batasuna votes and Null votes /*
*/ (in 2003, Null Votes).  \# Terror attacks is the number of ETA attacks in the municipality in the 10 years prior to the 2007 ban./*
*/ Close is a dummy equal to one if in 2003, the  absolute difference in vote share between Federal and Basque parties was below 10\%. /*
*/ The source of information about the ETA attacks is the Global Terrorism Database.}\\ /*
*/ \end{tabular}} ) replace

 

*********Controling for confounders and heterogeneous treatment effects********* 
drop _merge
sort ident
 
merge ident using Data/aux_kale

gen log_sumtotal=log(1+sumtotal)

foreach var in all_nationalists all_spanish bat_share{
gen `var'_preaux=`var' if year<2003
egen `var'_pre=mean(`var'_preaux), by(ident)
drop `var'_preaux
}
 
local i=0
foreach var in meancens_pre log_sumtotal log_all_pre10 all_nationalists_pre all_spanish_pre bat_share_pre{
local i=`i'+1
gen htpost_`i'=`var'*post
}
 
eststo clear
xtreg bat_call_share treatpost2007 htpost_1 htpost_2 htpost_3 $controlsfe $democontrols $if, fe cluster(ident)
est sto t10
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace 
estadd local ControlPost1 " Population, Terror, and" , replace 
estadd local ControlPost2 "Street Violence attacks" , replace 

xtreg bat_call_share treatpost2007 htpost_4 htpost_5 htpost_6 $controlsfe $democontrols $if, fe cluster(ident)
est sto t11
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace 
estadd local ControlPost1 " Nationalists, Batasuna, and " , replace 
estadd local ControlPost2 "  Spanish parties vote shares" , replace 


xtreg bat_call_share treatpost2007 htpost_*  $controlsfe $democontrols $if, fe cluster(ident)
est sto t12
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replac
estadd local ControlPost1 "\makecell{All}" , replace 
estadd local ControlPost2   , replace 

*All pairwise interactions
global c1 c.htpost_1#c.htpost_2 c.htpost_1#c.htpost_2 c.htpost_1#c.htpost_3 c.htpost_1#c.htpost_4 c.htpost_1#c.htpost_5 c.htpost_1#c.htpost_6
global c2 c.htpost_2#c.htpost_3 c.htpost_2#c.htpost_4 c.htpost_2#c.htpost_5 c.htpost_2#c.htpost_6
global c3 c.htpost_3#c.htpost_4 c.htpost_3#c.htpost_5 c.htpost_3#c.htpost_6
global c4 c.htpost_4#c.htpost_5 c.htpost_4#c.htpost_6 c.htpost_5#c.htpost_6


xtreg bat_call_share treatpost2007 $c1 $c2 $c3 $c4 $controlsfe $democontrols $if, fe cluster(ident)
est sto t13
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replac
estadd local ControlPost1 "All" , replace 
estadd local ControlPost2 "+ pairwise interactions" , replace 


esttab t10 t11 t12 t13  using paper/taula_controls.tex,  se keep(treatpost2007) /*
*/ tex gaps  coeflabels(treatpost2007 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$" ) /*
*/  nomtitles mgroups(  "\makecell{Batasuna Support}" , pattern(1 0 0 0  ) prefix(\multicolumn{@span}{c}{) suffix(}) span  )   /*
*/   s( MuniFE PBPYearFE ControlPost1 ControlPost2  N N_clust, label(  "\addlinespace[1ex] Municipality FE" "Pre-ban presence $\times$ election FE" "Pre-ban characteristics" "$\times$ Post 2007" "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{5}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses. /*
*/ Support for Batasuna is measured as the sum of Batasuna votes and Null votes, as a fraction of total votes. /*
*/ Population is measured with the average municipality size before the ban. Terror attacks/*
*/ are measured with the log of terror attacks from 1997 to 2006, Street Violence attacks are measured with the log of street violence attacks from April 2006 to April 2007. /*
*/ All political variable controls are pre-2003 averages. Nationalist support is the sum of Support for Batasuna, PNV, EA, PNV-EA, and Aralar, as a fraction of total votes. /*
*/ Spanish support is the sum of support for PP, CDS, UA, PSOE, PSOE, and IU, as a fraction of total votes. /* 
*/ In all regressions, 2007 is excluded from the sample. All regressions control for a cubic in municipality size. /*
*/ Estimates weighted according to entropy balance weights, as described in the text.}\\ /*
*/ \end{tabular}} ) replace

********************************************************************************


*******************Heterogeneous effects by pre-ban support*********************

gen auxvarpre=bat_share if year<2003
egen var_bat_share_pre=sd(auxvarpre), by(ident)
replace var_bat_share_pre=var_bat_share_pre^2

sum bat_share_pre if year==2011
gen dm_bat_share_pre=bat_share_pre-`r(mean)'

sum var_bat_share_pre if year==2011
replace var_bat_share_pre=var_bat_share_pre-`r(mean)'

 
eststo clear
quietly  reghdfe bat_call_share  newtreatpost2007    c.newtreatpost2007#c.dm_bat_share_pre c.post#c.dm_bat_share_pre cens cens2 cens3 if year!=2007 & year!=2003, absorb( year year#groupleg ident) vce(cluster ident) 

est sto ev1
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local a1 "$\checkmark$" , replace
sum dm_bat_share_pre if year==2011
 
 
quietly  reghdfe bat_call_share  newtreatpost2007    c.newtreatpost2007#c.dm_bat_share_pre c.post#c.dm_bat_share_pre  c.newtreatpost2007#c.var_bat_share_pre c.post#c.var_bat_share_pre cens cens2 cens3 if year!=2007 & year!=2003, absorb( year year#groupleg ident) vce(cluster ident) 
est sto ev2
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local a1 "$\checkmark$" , replace
estadd local a2 "$\checkmark$" , replace
sum var_bat_share_pre if year==2011
 


esttab ev1 ev2 using paper/tab_ev.tex,  se keep( newtreatpost2007    c.newtreatpost2007#c.dm_bat_share_pre   c.newtreatpost2007#c.var_bat_share_pre  ) /*
*/ tex gaps  coeflabels(newtreatpost2007 "\addlinespace[1ex] \$I(\text{Year}\geq\text{2007}) \times I(\text{Ban in 2007})$" /*
*/  c.newtreatpost2007#c.dm_bat_share_pre "\addlinespace[1ex] \$I(\text{Year}\geq\text{2007}) \times I(\text{Ban in 2007}) \times \text{ Pre-Ban Support} $" /*
*/  c.newtreatpost2007#c.var_bat_share_pre "\addlinespace[1ex] \$I(\text{Year}\geq\text{2007}) \times I(\text{Ban in 2007}) \times \text{ Variance of Pre-Ban Support} $")  /*
*/  nomtitles mgroups( "Batasuna Support" , pattern(1 0   ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})  )   /*
*/   s(  MuniFE PBPYearFE a1 a2 N N_clust, label("\addlinespace[1ex] Municipality FE" "Pre-ban presence $\times$ election FE" /*
*/  " \$I(\text{Year}\geq\text{2007}) \times \text{ Pre-Ban Support} $" "\$I(\text{Year}\geq\text{2007}) \times \text{Variance of Pre-Ban Support}$"  /*
*/ "N"  "Municipalities"))  star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{3}{{p{\linewidth}}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses. /*
*/ Support for Batasuna is measured as the sum of Batasuna votes and Null votes. Pre-ban support is a 1987-1999 average. All interacted variables are in deviations with respect to the cross-sectional mean. /*
*/ Range of pre-ban support: [-0.215,0.532]. Range of (de-meaned) variance of pre-ban support: [ -0.0102,0.2626]. /*
*/  All regressions control for a cubic in municipality size. Sample: excluding 2003 and 2007.}\\ /*
*/ \end{tabular}} ) replace

********************************************************************************





 
********************************************************************************
************************************IV******************************************
 
 
 
egen cscgroup=group(csc_post)
egen cscpre=group(csc)

egen meanbat_ddd=mean(bat_call_share), by(year dum_three dum_elected)
egen meanpres_ddd=mean(bat_present), by(year dum_three dum_elected)
 
*****************************Triple difference figures**************************
*First Stage
twoway  (connected meanbat_ddd year if dum_three==0 & dum_elected==0 , sort xline(2007)) /*
*/ (connected meanbat_ddd year if dum_three==0 & dum_elected==1, sort) /*
*/ (connected meanbat_ddd year if dum_three==1 & dum_elected==0, sort) /*
 */(connected meanbat_ddd year if dum_three==1 & dum_elected==1 , sort /*
*/ xlabel(1987(4)2015) ytitle("Percentage") xtitle("Election year")   /*
*/  legend( order( 1 "FCa<3, FCo=0" 2 "FCa<3, FCo=1" 3 "FCa>2, FCo=0" 4 "FCa>2, FCo=1" ) size(small) )),  aspectratio(.4) graphregion(color(white)) bgcolor(white)  

quietly graph export "paper/ddd_rf.eps", as(eps) replace


*Reduced Form
twoway  (connected meanpres_ddd year if dum_three==0 & dum_elected==0 & year<=2007 , sort xline(2007)) /*
*/ (connected meanpres_ddd year if dum_three==0 & dum_elected==1 & year<=2007, sort) /*
*/ (connected meanpres_ddd year if dum_three==1 & dum_elected==0 & year<=2007, sort) /*
 */(connected meanpres_ddd year if dum_three==1 & dum_elected==1 & year<=2007 , sort /*
*/ xlabel(1987(4)2007) ytitle("Percentage") xtitle("Election year")  /*
*/  legend( order( 1 "FCa<3 FCo=0" 2 "FCa<3, FCo=1" 3 "FCa>2, FCo=0" 4 "FCa>2, FCo=1" ) size(small) )),  aspectratio(.4) graphregion(color(white)) bgcolor(white)  

quietly graph export "paper/ddd_fs.eps", as(eps) replace





****************************IV estimates****************************************

eststo clear
*controls
global baseiv  i.ident i.year  dum_elected_post i.cscgroup    


*Baseline

*First, partial out outcome, endogenous var, and instrument of controls, then wald

global iv1 $baseiv
global ifiv1 if year!=2007 
quietly reg bat_call_share $iv1 $democontrols $ifiv1
predict outiv1 $ifiv1, res
quietly reg treatment_post $iv1 $democontrols $ifiv1
predict ziv1 $ifiv1, res
quietly reg treatpost2007 $iv1 $democontrols $ifiv1
predict xiv1 $ifiv1, res
ivreg2   outiv1 (xiv1=ziv1)  $ifiv1 , cluster(ident)  first

est sto t8c1
local b = _b[xiv1]
local se = _se[xiv1]
local t = `b'/`se'
local f=e(widstat)
local f=round(`f',0.001)
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local FCaPost "$\checkmark$"  , replace
estadd local FCoPost  "$\checkmark$"  , replace
estadd local KP  `f'  , replace



*First stage of the baseline
 
ivreg2   xiv1 ziv1  $ifiv1 , cluster(ident)  
local b = _b[ziv1]
local se = _se[ziv1]
local t = `b'/`se'
 
est sto t7c1
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local FCaPost "$\checkmark$"  , replace
estadd local FCoPost  "$\checkmark$"  , replace
estadd local KP  `f'  , replace

 esttab t7c1 using paper/first_stage.tex , se keep(ziv1) /*
*/ tex gaps  coeflabels(ziv1 "\addlinespace[1ex] $ I(FCo \geq 1)   \times I(FCa\geq 3)\times I(\text{Post 2007})  $ " )  /* 
*/  mtitles("\$I(\text{Post 2007}) \times I(\text{Ban in 2007})$")   /*
*/   s(MuniFE YearFE FCaPost FCoPost KP N  N_clust, label(  /*
*/ "\addlinespace[1ex] Municipality FE" "Year FE " "Former Candidates FE $\times$ I(\text{Post 2007})" "  \$I(FCo \geq 1)$ $\times$ I(\text{Post 2007}) " "\hline Kleibergen-Paap F" "N"   " Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{2}{p{\linewidth}/*
*/}{\footnotesize Standard errors clustered at the municipality level in parentheses. /*
*/ 2007 is excluded from the sample. /*
*/ All regressions control for a cubic in municipality size.}\\ /*
*/ \end{tabular} } ) replace





gen withindifa=withindif if year==2007 
gen bat_present_2007a=bat_present_2007 if year==2007 
egen withindifmean=mean(withindifa), by(csc dum_elected)
egen withintreat=mean(bat_present_2007a), by(csc dum_elected)
 

gen aux=1 if year==2007  
egen sumaux=sum(aux), by(csc dum_elected)
gen cscneg=-csc


twoway (connected withintreat cscneg  if dum_elected==1  & withindifmean!=.   [w=sumaux]  , sort msymbol(circle_hollow)) /*
*/  (connected withintreat cscneg  if dum_elected==0  [w=sumaux]  , sort msymbol(circle_hollow) xline(-0.5) /*
*/ note("Note: Normalized Former Candidates= -(Former Candidates-2)" "Circle sizes proportional to #municipalities per group", span pos(6))   subtitle("First Stage, Legal in 2007")/*
*/ ytitle("Legal in 2007") xtitle("Normalised Former Candidates") legend( order( 1 "Former Councilor" 2 "No Former Councilors" ) rows(2) size(small) )),   aspectratio(.3)  graphregion(color(white)) bgcolor(white)

quietly graph export "paper/first_stage.eps", as(eps) replace
 
 twoway (connected withindifmean cscneg if dum_elected==1  & withindifmean!=.   [w=sumaux]  , sort msymbol(circle_hollow)) /*
*/  (connected withindifmean cscneg if dum_elected==0  [w=sumaux]  , sort msymbol(circle_hollow) xline(-0.5) /*
*/ note("Note: Normalized Former Candidates= -(Former Candidates-2) " "Circle sizes proportional to #municipalities per group", span pos(6))   subtitle("Reduced form, (Support Post - Support Pre )") /*
*/ ytitle("Support Post - Support Pre") xtitle("Normalised Former Candidates") legend( order( 1 "Former Councilor" 2 "No Former Councilors" ) rows(2) size(small) )), aspectratio(.3)  graphregion(color(white)) bgcolor(white)

quietly graph export "paper/reduced_form.eps", as(eps) replace


**********************Other IV specifications*********************************** 

*Former candidate by former connected trends

capture drop outiv1 xiv1 ziv1
global iv1 $baseiv   c.csc_post##dum_elected_post       
global ifiv1 if year!=2007  

quietly reg bat_call_share $iv1 $democontrols  $ifiv1
predict outiv1, res
quietly reg treatment_post $iv1 $democontrols $ifiv1
predict ziv1, res
quietly reg treatpost2007 $iv1 $democontrols $ifiv1
predict xiv1, res
ivreg2 outiv1 (xiv1=ziv1)  $ifiv1 , cluster(ident) first

est sto t8c2
local b = _b[xiv1]
local se = _se[xiv1]
local t = `b'/`se'
local f=e(widstat)
local f=round(`f',0.001)
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local FCaPost "$\checkmark$"  , replace
estadd local FCoPost  "$\checkmark$"  , replace
estadd local FCaFCoPost  "$\checkmark$"  , replace
estadd local KP  `f'  , replace





****Only 2 or 3 former candidates
 
capture drop outiv1 xiv1 ziv1
global iv1 $baseiv
global ifiv1 if year!=2007 & year>=1987 & (csc>=0 & csc<=1) 
quietly reg bat_call_share $iv1 $democontrols $ifiv1
predict outiv1 $ifiv1, res
quietly reg treatment_post $iv1 $democontrols $ifiv1
predict ziv1 $ifiv1, res
quietly reg treatpost2007 $iv1 $democontrols $ifiv1
predict xiv1 $ifiv1, res
ivreg2 outiv1 (xiv1=ziv1)  $ifiv1 , cluster(ident) first

est sto t8c4
local b = _b[xiv1]
local se = _se[xiv1]
local t = `b'/`se'
local f=e(widstat)
local f=round(`f',0.001)
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local FCaPost "$\checkmark$"  , replace
estadd local FCoPost  "$\checkmark$"  , replace
estadd local Thresh  "$\checkmark$"  , replace
estadd local KP  `f'  , replace



 
****Excluding municipalities with missing links
 

capture drop outiv1 xiv1 ziv1
global iv1 $baseiv  c.csc_post##dum_elected_post no_data##post  
global ifiv1 if year!=2007  & no_data==0

quietly reg bat_call_share $iv1 $democontrols $ifiv1
predict outiv1, res
quietly reg treatment_post $iv1 $democontrols $ifiv1
predict ziv1, res
quietly reg treatpost2007 $iv1 $democontrols $ifiv1
predict xiv1, res
ivreg2 outiv1 (xiv1=ziv1)  $ifiv1 , cluster(ident) first

est sto t8c3
local b = _b[xiv1]
local se = _se[xiv1]
local t = `b'/`se'
local f=e(widstat)
local f=round(`f',0.001)
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local FCaPost "$\checkmark$"  , replace
estadd local FCoPost  "$\checkmark$"  , replace
estadd local FCaFCoPost  "$\checkmark$"  , replace
estadd local Nodat  "$\checkmark$"  , replace
estadd local KP  `f'  , replace



 esttab t8c1 t8c2 t8c3 t8c4 using paper/ivlocal.tex , se keep(xiv1) /*
*/ tex gaps  coeflabels(xiv1 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$  " ) /* 
*/  mtitles("Batasuna Support"   "Batasuna Support" "Batasuna Support"   "Batasuna Support")   /*
*/   s( MuniFE YearFE FCaPost FCoPost FCaFCoPost Nodat Thresh KP N N_clust, label( "\addlinespace[1ex] Municipality FE" "Year FE" /*
*/ "Former Candidates FE $\times$ I(\text{Post 2007})" " \$I(FCo \geq 1)$ $\times$ I(\text{Post 2007})" "$ FCa$ $\times$  \$I(FCo \geq 1)$ $\times$ I(\text{Post 2007})"/*
*/ "Excluding missing links " "Only \$FCa=2$ or \$FCa=3$" "\hline Kleibergen-Paap F "  "N" "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{5}{p{\linewidth}/*
*/}{\footnotesize Standard errors clustered at the municipality level in parentheses. /*
*/ Support for Batasuna is measured as the sum of Batasuna votes and Null votes. In all regressions, 2007 is excluded from the sample. /*
*/ All regressions control for a cubic in municipality size. }\\ /*
*/ \end{tabular}} ) replace


