 
 



********************************************************************************
*********This produces the output and analysis for regional elections***********
********************************************************************************

clear 
set more off 
set matsize 800

cd ${basedir}


clear 
use Data/global_dta.dta, replace
*Take regional elections in the Basque Country
keep if tipo==5  

sort codi_mun codi_pro
*Add some information on local election results
merge codi_mun codi_pro using Data/aux_regional.dta

gen post=1
replace post=0 if year<2007

*Create treatment variables and placebos
gen treatpost2007=m_bat_present_2007*post
replace treatpost2007=-treatpost2007

gen platreatpost2007=m_bat_present_2007
replace platreatpost2007=0 if year<2005
replace platreatpost2007=-platreatpost2007
*********************************************
 

replace bat_call_share=(batasuna+nuls)/(acandi+blancs+nuls)

*Define some of the yearly variables in cross-section
foreach z in 1986 1990 1994 1998 2001 2005 2009 2012{
gen bat_share_`z'aux=bat_share if year==`z'
egen bat_share_`z'=max(bat_share_`z'aux), by(codi_mun codi_pro)
gen bat_call_share_`z'aux=bat_call_share if year==`z'
egen bat_call_share_`z'=max(bat_call_share_`z'aux), by(codi_mun codi_pro)

gen share_ea_`z'aux=share_ea if year==`z'
egen share_ea_`z'=max(share_ea_`z'aux), by(codi_mun codi_pro)

gen share_pnv_`z'aux=share_pnv if year==`z'
egen share_pnv_`z'=max(share_pnv_`z'aux), by(codi_mun codi_pro)

gen share_pnvea_`z'aux=share_pnvea if year==`z'
egen share_pnvea_`z'=max(share_pnvea_`z'aux), by(codi_mun codi_pro)

gen share_aralar_`z'aux=share_aralar if year==`z'
egen share_aralar_`z'=max(share_aralar_`z'aux), by(codi_mun codi_pro)

drop bat_share_`z'aux bat_call_share_`z'aux share_pnv_`z'aux share_ea_`z'aux share_pnvea_`z'aux share_aralar_`z'aux
}
drop _merge
sort codi_mun codi_pro
save Data/aux_regdesc.dta, replace

egen groupleg=group(m_bat_present_1987 m_bat_present_1991 m_bat_present_1995 m_bat_present_1999)
gen cens2=cens^2
gen cens3=cens^3
   
  
***************TABLE: EFFECT ON SUPPORT IN REGIONAL ELECTIONS******************* 
global democontrols cens cens2 cens3
xtset ident


********baseline
eststo clear
quietly xtreg bat_call_share treatpost2007 year#codi_pro  year#groupleg $democontrols  , fe cluster(ident)
est sto t3c1
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local ProvYearFE "$\checkmark$" , replace

********with placebo (lead)
quietly xtreg bat_call_share platreatpost2007 treatpost2007 year#codi_pro  year#groupleg $democontrols  , fe cluster(ident)
est sto t3c2
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local ProvYearFE "$\checkmark$" , replace
estadd local Plac "$\checkmark$" , replace
 
 

*****with control for pre-ban votes (immediate loss in support)
capture gen m_bat_call_share_pre_post=post*(m_bat_call_share_1987+ m_bat_call_share_1991 +m_bat_call_share_1991 +m_bat_call_share_1995 +m_bat_call_share_1999+ m_bat_call_share_2003)/6
egen rmean_pre_post=rmean(m_bat_call_share_1987 m_bat_call_share_1991  m_bat_call_share_1995 m_bat_call_share_1999 m_bat_call_share_2003)
replace m_bat_call_share_pre_post=post*rmean_pre_post



quietly xtreg bat_call_share platreatpost2007 treatpost2007 m_bat_call_share_pre_post year#codi_pro year#groupleg  $democontrols, fe cluster(ident)
est sto t3c3
estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local ProvYearFE "$\checkmark$" , replace
estadd local Plac "$\checkmark$" , replace
estadd local Prepostsup "$\checkmark$" , replace
 

*with control for immediate loss in support too 
gen m_bat_call_share_post_post=post*(m_bat_call_share_2007)
gen m_bat_share_2011_post=m_bat_call_share_2011
replace m_bat_share_2011_post=0 if year<=2009 


quietly xtreg bat_call_share platreatpost2007 treatpost2007 m_bat_call_share_pre_post m_bat_call_share_post_post year#codi_pro year#groupleg  $democontrols, fe cluster(ident)
est sto t3c4

estadd local MuniFE "$\checkmark$" , replace
estadd local PBPYearFE "$\checkmark$" , replace
estadd local ProvYearFE "$\checkmark$" , replace
estadd local Plac "$\checkmark$" , replace
estadd local Prepostsup "$\checkmark$" , replace
estadd local Postpostsup "$\checkmark$" , replace


esttab t3c1 t3c2 t3c3 t3c4 using paper/tabreg1.tex, se keep(treatpost2007 platreatpost2007) /*
*/ tex gaps unstack coeflabels(treatpost2007 " \addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$" /*
*/ platreatpost2007 "\$I(\text{Post 2005}) \times I(\text{Ban in 2007})$"  \addlinespace[1ex]) /*
*/  nomtitles mgroups("Batasuna Support", pattern(1 0 0 0  ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}) )   /*
*/   s( MuniFE ProvYearFE PBPYearFE Prepostsup Postpostsup N N_clust, label(  " \addlinespace[1ex] Municipality FE" "Province $\times$ election FE" "Pre-ban presence $\times$ election FE" /*
*/ "\$I(\text{Post 2007}) \times \text{Pre-ban Support (local)}$" "\$I(\text{Post 2007}) \times \text{Support in 2007 (local)}$" "N"  "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot( \hline\hline\multicolumn{5}{p{\linewidth}}{\footnotesize /*
*/ Standard errors clustered at the municipality level in parentheses./*
*/ In 2009, the vote share of Batasuna is computed as the share of null votes. Pre-ban support and support in 2007 refer to local elections. All regressions control for a cubic in municipality size.}\\ /*
*/ \end{tabular}} ) replace

 


********************************************************************************
***********************IV RESULTS, REGIONAL ELECTIONS***************************
********************************************************************************




  
 
gen csc_post=csc*post
gen dum_elected_post=dum_elected*post
gen dum_three_post=dum_three*post
gen treatment_post=treatment*post

egen cscgroup=group(csc_post)
egen cscpre=group(csc)


*Baseline

*First, partial out outcome, endogenous var, and instrument of controls, then wald
 
capture drop outiv1 xiv1 ziv1
global baseiv i.ident i.year dum_elected_post i.cscgroup   
global iv1 $baseiv
global ifiv1 
quietly reg bat_call_share $iv1 $democontrols $ifiv1
quietly predict outiv1, res
quietly reg treatment_post $iv1 $democontrols $ifiv1
quietly predict ziv1, res
quietly reg treatpost2007 $iv1 $democontrols $ifiv1
predict xiv1, res
ivreg2 outiv1 (xiv1=ziv1)  $ifiv1 , cluster(ident) 

est sto t9c1
local b = _b[xiv1]
local se = _se[xiv1]
local t = `b'/`se'
local f=e(widstat)
local f=round(`f',0.001)
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local FCaPost "$\checkmark$"  , replace
estadd local FCoPost  "$\checkmark$"  , replace
estadd local KP  `f'  , replace



*First stage
 
ivreg2   xiv1 ziv1  $ifiv1 , cluster(ident)  
local b = _b[ziv1]
local se = _se[ziv1]
local t = `b'/`se'
 

**********************Other IV specifications*********************************** 

*Former candidate by former connected trends 

capture drop outiv1 xiv1 ziv1
global iv1 $baseiv c.csc_post##dum_elected_post  
global ifiv1  
quietly reg bat_call_share $iv1 $democontrols $ifiv1
quietly predict outiv1, res
quietly reg treatment_post $iv1 $democontrols $ifiv1
quietly predict ziv1, res
quietly reg treatpost2007 $iv1 $democontrols $ifiv1
predict xiv1, res
ivreg2 outiv1 (xiv1=ziv1)  $ifiv1 , cluster(ident) 

est sto t9c2
local b = _b[xiv1]
local se = _se[xiv1]
local t = `b'/`se'
local f=e(widstat)
local f=round(`f',0.001)
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local FCaPost "$\checkmark$"  , replace
estadd local FCoPost  "$\checkmark$"  , replace
estadd local FCaFCoPost  "$\checkmark$"  , replace
estadd local KP  `f'  , replace


****Only 2 or 3 former candidates

 
capture drop outiv1 xiv1 ziv1
global iv1 $baseiv 
global ifiv1 if   (csc>=0 & csc<=1)
quietly reg bat_call_share $iv1 $democontrols $ifiv1
predict outiv1 $ifiv1, res
quietly reg treatment_post $iv1 $democontrols $ifiv1
predict ziv1 $ifiv1, res
quietly reg treatpost2007 $iv1 $democontrols $ifiv1
predict xiv1 $ifiv1, res
ivreg2 outiv1 (xiv1=ziv1)  $ifiv1 , cluster(ident) first


est sto t9c4
local b = _b[xiv1]
local se = _se[xiv1]
local t = `b'/`se'
local f=e(widstat)
local f=round(`f',0.001)
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local FCaPost "$\checkmark$"  , replace
estadd local FCoPost  "$\checkmark$"  , replace
estadd local Thresh  "$\checkmark$"  , replace
estadd local KP  `f'  , replace


****Excluding municipalities with missing links


capture drop outiv1 xiv1 ziv1
global iv1 $baseiv  c.csc_post##dum_elected_post no_data##post  
global ifiv1  if no_data==0

quietly reg bat_call_share $iv1 $democontrols $ifiv1
predict outiv1, res
quietly reg treatment_post $iv1 $democontrols $ifiv1
predict ziv1, res
quietly reg treatpost2007 $iv1 $democontrols $ifiv1
predict xiv1, res
ivreg2 outiv1 (xiv1=ziv1)  $ifiv1 , cluster(ident) first

est sto t9c3
local b = _b[xiv1]
local se = _se[xiv1]
local t = `b'/`se'
local f=e(widstat)
local f=round(`f',0.001)
estadd local MuniFE "$\checkmark$" , replace
estadd local YearFE "$\checkmark$" , replace
estadd local FCaPost "$\checkmark$"  , replace
estadd local FCoPost  "$\checkmark$"  , replace
estadd local FCaFCoPost  "$\checkmark$"  , replace
estadd local Nodat  "$\checkmark$"  , replace
estadd local KP  `f'  , replace
 
 




 esttab t9c1 t9c2 t9c3 t9c4 using paper/ivregional.tex , se keep(xiv1) /*
*/ tex gaps  coeflabels(xiv1 "\addlinespace[1ex] \$I(\text{Post 2007}) \times I(\text{Ban in 2007})$  " ) /* 
*/  mtitles("Batasuna Support"   "Batasuna Support" "Batasuna Support"   "Batasuna Support")   /*
*/   s( MuniFE YearFE FCaPost FCoPost FCaFCoPost Nodat Thresh KP N N_clust, label( "\addlinespace[1ex] Municipality FE" "Year FE" /*
*/ "Former Candidates FE $\times$ I(\text{Post 2007})" " \$I(FCo \geq 1)$ $\times$ I(\text{Post 2007})" "$ FCa$ $\times$  \$I(FCo \geq 1)$ $\times$ I(\text{Post 2007})"/*
*/ "Excluding missing links " "Only \$FCa=2$ or \$FCa=3$" "\hline Kleibergen-Paap F "  "N" "Municipalities")) /*
*/ star(* 0.0000000000000000000001) nonotes postfoot(\hline\hline \multicolumn{5}{p{\linewidth}/*
*/}{\footnotesize Standard errors clustered at the municipality level in parentheses. /*
*/ All regressions control for a cubic in municipality size. }\\ /*
*/ \end{tabular}} ) replace
