



********************************************************************************
***********PARTY BANS, DETERRENCE OR BACKLASH? REPLICATION PACKAGE**************
***************************README FILES ****************************************
********************************************************************************



*****************OS and Software versions and requirements**********************
/* -This code was run with Stata 16.0 MP and Windows 10. 				   	*/

																			
																			
**************************Setting the base directory*****************************																			
clear all
*Simply replace the path to wherever you downloaded the replication folder
capture global basedir "/Users/zhaosongruan/Desktop/replication"
capture cd ${basedir}

******************************Add-ons used**************************************
*Uninstall all current packages that will be used
capture adoupdate
foreach addon in binscatter esttab ftools reghdfe distinct ivreg2 ranktest unique shp2dta spmap ebalance strgroup coefplot{
capture ado uninstall `addon' 
}
ado
*This should show no packages installed
********************************************************************************
*Now, we copy the packages from the folder, so that if there are changes over time
*in the version of the package, the code still replicates

*Instructions for replication:
*1) Type sysdir, and replace "c:/ado/plus" below by the PLUS folder given by Stata
*2) This copies the packages into the current ado directory
 
!xcopy "${basedir}/Statapackages" "c:/ado/plus"    /i /y /e /d
reghdfe, compile
ftools, compile

/*Note regarding strgroup:
The strgroup plugin changes across OS. In this case (Windows), it is
strgroup.pc(64-bit_x86-64).windows.plugin. If you are using another OS, the 
Stata folder contains the plugins for them, just replace strgroup.plugin for
the strgroup plugin file of your OS, and rename it as strgroup.plugin */

/*For completenes, these are the packages from ssc
foreach addon in binscatter estout ftools reghdfe distinct ivreg2 ranktest unique shp2dta spmap ebalance strgroup{
ssc install `addon', all replace
}  */


********************************************************************************
********From here, the code is ready to be run and produce all the output*******

********************************Other*******************************************
*This sets the color scheme for figures
global symbolscolors  msymbols(O S) colors(gs4 gs10)
*This makes the code run all at once
set more off


********************************************************************************
*************************DATA CLEANING AND SET-UP******************************* 
********************************************************************************

/*0- Delete all files, to start from scratch */
foreach database in aux_regdesc aux_regional aux_heterogeneity aux_kale kale_buesa police /*
*/ ready_to_output codis_mun global_dta terror_tomerge{
capture erase Data/`database'.dta
}

/*1 - Takes raw data on regional elections and cleans it, creating peusk.dta and pjeusk.dta */
*The data on basque regional elections can be downloaded from the Basque government site,
*https://www.euskadi.eus/informacion/descargas-de-ficheros-de-resultados-de-elecciones/web01-a2haukon/es/
do "${basedir}/dofiles/replication_1_stata16.do" 

/*2 - Takes raw data on local elections and cleans it. Appends p_eusk.dta and creates global_dta.dta and electoral_results_ministeri.dta */
*The raw data on local elections can be downloaded from the Spanish government site,
*http://www.infoelectoral.mir.es/infoelectoral/min/areaDescarga.html
do "${basedir}/dofiles/replication_2_stata16.do" 
/*
Note: if while running this file, this error appears: file X.dta cannot be modified or erased; likely cause is read-only directory or file
Simply increase the sleep parameter in the do_file. Explanation: 
This may happen because if the saving file is (or becomes) very large, and the loop otherwise executes quickly, 
it is possible that the operating system is not done writing out the last version of the file 
(disk output is very slow compared to computation) when it gets Stata's next request to write out the next version,
and at that point the OS may tell Stata the file is inaccessible because it is still busy.
If this is what is happening, the solution is to put a -sleep- command into the loop just after the -save- command.
That will make Stata wait long enough for the file-write operations to completely finish before proceeding to the next iteration of the loop.
*/

/*3  - Takes terrorism database and cleans it, creates  terror_tomerge.dta */
*Can be downloaded from https://www.start.umd.edu/gtd/
do "${basedir}/dofiles/replication_3_stata16.do" 

/*4 - Takes raw data on electoral lists, cleans it, and creates police.dta  */
do "${basedir}/dofiles/replication_4_stata16.do" 
/*This file takes the documentation on linked candidates in 2 steps. 
*1) From an excel that contains all the text in the original pdf source, which is
in (Documents_IV/links_libertad_digital.pdf), and directly inputting values from
from the public prosecutor denounce(pages 36 to 56 in  Documents_IV/demanda-fiscalia.pdf
*/
/*5 - Takes takes global_dta, merges with police.dta, and creates ready to output.dta  */
do "${basedir}/dofiles/replication_5_stata16.do" 

/*6 - Takes raw data and cleans it and produces kale_buesa.dta */
*This file takes the list of street terror attacks of an excel copied from the
*pdf by Buesa (2008) in /Documents_kale/Actividades terroristas de ETA Julio-2008.pdf, 
do "${basedir}/dofiles/replication_6_stata16.do" 

********************************************************************************
****************************ANALYSIS******************************************** 
********************************************************************************

*Note: the .dta files that are necessary for this part can also be found in the Data back-up folder,
* in case the replicator does not want to go through do-files 1 to 6.  

/*7 - Takes takes ready_to_output.dta, merges with terror_tomerge and produces the latex output for local elex  */
do "${basedir}/dofiles/replication_7_stata16.do" 

/*8 - Takes global_dta ready_to_output.dta, and produces the latex output for regional elex  */
do "${basedir}/dofiles/replication_8_stata16.do" 

/*9 - Takes kale_buesa.dta and produces kale output */
do "${basedir}/dofiles/replication_9_stata16.do"  

/*10 - Takes ready_to_output, global_dta, and kale_buesa, and produces the latex output for all descriptives
except correlates of vote loss, which is in replication_7 */
do "${basedir}/dofiles/replication_10_stata16.do"  

/*11 - Maps: Takes ready_to_output.dta and the map coordinate file (CB_MUNICIPIOS_5000_ETRS89)
and produces the maps */ 
do "${basedir}/dofiles/replication_11_stata16.do" 
